/*
 *This is application code of Great Little Radio Player
 *It is written by Dejan Petrovic
 *dekiseka.petrovic@gmail.com
 */

#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "adddialog.h"
#include "settings.h"
#include "aboutdialog.h"

#include "phonon/AudioDataOutput"
#include "phonon/Global"
#include "phonon/MediaObject"
#include "phonon/AudioOutput"
#include <phonon/MediaSource>
#include <phonon/BackendCapabilities>
#include <phonon/VolumeSlider>

#include <QtCore/QFile>
#include <QDir>
#include "QtGui"
#include <QtCore/QTextStream>
#include <QDialog>
#include <QAction>
#include <QMenu>
#include "QMessageBox"
#include "QStringRef"
#include <QTimer>
#include "QPixmap"
#include "QDesktopWidget"
#include "QPushButton"
#include <QDesktopWidget>
#include <QList>
#include <QPixmap>
#include "QTableWidgetItem"
#include <QFlags>
#include <QRegExp>
#include <QStringList>
#include <QSettings>
#include <QPalette>
#include <QLayout>
#include <QShortcut>
#include <QApplication>
#include <QProcess>
#include <QX11Info>

//------------------------------------------------------------------------------------
MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent), ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    ui->IMGLabel->setToolTip(QApplication::applicationName() + "<br>" + QApplication::applicationVersion());
    ui->IconWidget->setToolTip(QApplication::applicationName() + "<br>" + QApplication::applicationVersion());

    ui->PauseButton->setParent(ui->StopButton);
    ui->PauseButton->setObjectName("PauseButton");
    ui->PauseButton->setFlat(true);

    //Procitaj i postavi jezik
    QSettings temp_settings("glrp", "Great Little Radio Player");
    temp_settings.beginGroup("OtherSettings");
    ReadLanguage(temp_settings.value("UILanguage", "English").toString());
    temp_settings.endGroup();
    //-----------------------

    music = new Phonon::MediaObject(this);
    music->setObjectName("music");
    audioOutput = new Phonon::AudioOutput(this);
    audioOutput->setObjectName("audioOutput");
    Phonon::createPath(music, audioOutput);

    audioDataOutput = new Phonon::AudioDataOutput(this);
    audioDataOutput->setObjectName("AudioDataOutput");
    Phonon::createPath(music, audioDataOutput);

    audioOutput->setVolume(0.7);

    volumeSlider = new Phonon::VolumeSlider;
    volumeSlider->setAudioOutput(audioOutput);
    volumeSlider->setOrientation(Qt::Horizontal);
    volumeSlider->setObjectName("volumeSlider");
    volumeSlider->setMuteVisible(false);
    volumeSlider->setMaximumWidth(150);

    volumeSlider2 = new Phonon::VolumeSlider;
    volumeSlider2->setAudioOutput(audioOutput);
    volumeSlider2->setOrientation(Qt::Vertical);
    volumeSlider2->setWindowFlags(Qt::Popup);
    volumeSlider2->setObjectName("volumeSlider2");
    volumeSlider2->setMuteVisible(false);
    volumeSlider2->setMinimumHeight(200);
    volumeSlider2->setMaximumHeight(200);

    tableWidget = new QTableWidget();

    CheckVersion();
    SloveIfStationFileNotExists();
    Load_stations(PathToStationsFile);
    RefreshGenreCountryList("Genre");
    StatusGenre = true;
    ShowFavorites();
    ui->widget->hide();
    ui->StationslistWidget->setContextMenuPolicy(Qt::CustomContextMenu);

    try
    {
    setWindowIcon(QIcon(":/images/IMG/radio-tray-white-32.png"));
    }
    catch(...){}

    readSettings();

    trayIcon = new QSystemTrayIcon(this);
    trayMenu = new QMenu(this);
    SystemTray(ShowStationsSystemTray);

DoAsYouReadSettings();
CreateConnection();

emptyWidget = new QWidget();
emptyWidget->setSizePolicy(QSizePolicy::Expanding,QSizePolicy::Preferred);
ui->toolBar->addWidget(emptyWidget);
ui->toolBar->addWidget(volumeSlider);
ui->toolBar->addAction(ui->actionFilter_station_list);

stateChanged(music->state(),music->state());
SetWindowStyle(HideAppCheckBox, StyleName);
ui->StationslistWidget->scrollToTop();

if (!trayIcon->isVisible())trayIcon->setVisible(true);
}
//------------------------------------------------------------------------------------
MainWindow::~MainWindow()
{Exit();}
//------------------------------------------------------------------------------------

void MainWindow::Exit()
{
    SaveStations();
    writeSettings();

    music->stop();
    delete music;
    delete audioOutput;
    delete trayIcon;

    close();
    delete ui;
    exit(0);

    QApplication::exit();
}

//------------------------------------------------------------------------------------
void MainWindow::CreateConnection()
{
    connect(ui->PauseButton, SIGNAL(clicked()),this, SLOT(Pause()));
    connect(ui->actionPause,SIGNAL(triggered()),this,SLOT(Pause()));
    music->connect(audioDataOutput,SIGNAL(dataReady(QMap<Phonon::AudioDataOutput::Channel,QVector<qint16> >)),this,SLOT(AudioSignalRecived(QMap<Phonon::AudioDataOutput::Channel,QVector<qint16> >)));
    connect(music, SIGNAL(bufferStatus(int)), this, SLOT(bufferStatusToTitle(int)));
    connect(music, SIGNAL(stateChanged(Phonon::State,Phonon::State)),this, SLOT(stateChanged(Phonon::State,Phonon::State)));
    connect(music, SIGNAL(metaDataChanged()),this, SLOT(metaDataChanged()));

    connect(ui->VolumeButton, SIGNAL(clicked()),this, SLOT(ShowVolumeWindow()));
    connect(ui->StationslistWidget, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(ShowContextMenu(const QPoint&)));
    connect(ui->action128x128, SIGNAL(triggered()), this, SLOT(UserIconSize()));
    connect(ui->action96x96, SIGNAL(triggered()), this, SLOT(UserIconSize()));
    connect(ui->action72x72, SIGNAL(triggered()), this, SLOT(UserIconSize()));
    connect(ui->action56x56_Icon, SIGNAL(triggered()), this, SLOT(UserIconSize()));
    connect(ui->action48x48, SIGNAL(triggered()), this, SLOT(UserIconSize()));
    connect(ui->action32x32_Icon, SIGNAL(triggered()), this, SLOT(UserIconSize()));
    connect(ui->action32x32_List, SIGNAL(triggered()), this, SLOT(UserIconSize()));
    connect(ui->action22x22_List, SIGNAL(triggered()), this, SLOT(UserIconSize()));
    connect(ui->action16x16_List, SIGNAL(triggered()), this, SLOT(UserIconSize()));
    connect(ui->action128x128, SIGNAL(hovered()), this, SLOT(UserIconSize()));
    connect(ui->action96x96, SIGNAL(hovered()), this, SLOT(UserIconSize()));
    connect(ui->action72x72, SIGNAL(hovered()), this, SLOT(UserIconSize()));
    connect(ui->action56x56_Icon, SIGNAL(hovered()), this, SLOT(UserIconSize()));
    connect(ui->action48x48, SIGNAL(hovered()), this, SLOT(UserIconSize()));
    connect(ui->action32x32_Icon, SIGNAL(hovered()), this, SLOT(UserIconSize()));
    connect(ui->action32x32_List, SIGNAL(hovered()), this, SLOT(UserIconSize()));
    connect(ui->action22x22_List, SIGNAL(hovered()), this, SLOT(UserIconSize()));
    connect(ui->action16x16_List, SIGNAL(hovered()), this, SLOT(UserIconSize()));

    connect(ui->actionAdd_new_station,SIGNAL(triggered()),this,SLOT(OpenAddNewStationDialog()));
    connect(ui->NewButton,SIGNAL(clicked()),this,SLOT(OpenAddNewStationDialog()));
    connect(ui->GenreCountryStringTreeWidget,SIGNAL(itemClicked(QTreeWidgetItem*,int)),this,SLOT(GenreCountryItemClicked(QTreeWidgetItem*,int)));
    connect(ui->StationslistWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(StationClicked(QListWidgetItem*)));
    connect(ui->StopButton,SIGNAL(clicked()),this,SLOT(StopRadioStationButton_clicked()));
    connect(ui->actionSort_stations_by_Country,SIGNAL(triggered()),this,SLOT(SortStationsByCountry()));
    connect(ui->CountryButton,SIGNAL(clicked()),this,SLOT(SortStationsByCountry()));
    connect(ui->actionSort_stations_by_Genre,SIGNAL(triggered()),this,SLOT(SortStationsByGenre()));
    connect(ui->GenreButton,SIGNAL(clicked()),this,SLOT(SortStationsByGenre()));
    connect(ui->actionList_all_Favorites,SIGNAL(triggered()),this,SLOT(ShowFavorites()));
    connect(ui->FavoriteButton,SIGNAL(clicked()),this,SLOT(ShowFavorites()));
    connect(ui->actionHide_player,SIGNAL(triggered()),this,SLOT(ShowHideWindow()));
    connect(ui->HideButton,SIGNAL(clicked()),this,SLOT(ShowHideWindow()));
    connect(ui->actionFilter_station_list,SIGNAL(triggered()),this,SLOT(FilterStations()));
    connect(ui->actionSettings,SIGNAL(triggered()),this,SLOT(OpenSettingsDialog()));
    connect(ui->SettingsButton,SIGNAL(clicked()),this,SLOT(OpenSettingsDialog()));
    connect(ui->actionExpand_Collapse,SIGNAL(triggered()),this,SLOT(ExpandCollapse()));
    connect(ui->MaxRestButton,SIGNAL(clicked()),this,SLOT(MaximizeRestore()));
    connect(ui->actionExit,SIGNAL(triggered()),this,SLOT(Exit()));
    connect(ui->ExitButton,SIGNAL(clicked()),this,SLOT(Exit()));
    connect(ui->actionImport_stations_from_file,SIGNAL(triggered()),this,SLOT(ImportStationsFromFile()));
    connect(ui->actionAll_about,SIGNAL(triggered()),this,SLOT(OpenAboutDialog()));
    connect(ui->actionExport_all_stations,SIGNAL(triggered()),this,SLOT(ExportStations()));
    connect(ui->actionEdit_stations_file,SIGNAL(triggered()),this,SLOT(EditStationsFile()));
    connect(ui->actionMenu,SIGNAL(triggered()),this,SLOT(OpenMenu()));
}
//------------------------------------------------------------------------------------
void MainWindow::AudioSignalRecived(const QMap<Phonon::AudioDataOutput::Channel, QVector<qint16> >& data)
{
   audiopodatci = data;
   update();
}
//------------------------------------------------------------------------------------
void MainWindow::paintEvent(QPaintEvent *event)
{
    if (EnableVisualisation)
    {
    int sirina = size().width();
    int visina = size().height();

    QPainter painter(this);
        painter.beginNativePainting();
        painter.setWindow(5,0,sirina,visina);
        painter.setBrush(Qt::transparent);

    QPainterPath levikanal, desnikanal;

    int y = 0;
    int x = 0;
    double LeftVPosition = (((double)LeftChannelPosition)/10)/2;
    double RightVPosition = (((double)RightChannelPosition)/10)/2;

    int uzorak = audiopodatci[Phonon::AudioDataOutput::LeftChannel].size();
    for(int i = 0; i < uzorak; i++)
        {
        x = (i*sirina)/uzorak;

        y = (audiopodatci[Phonon::AudioDataOutput::LeftChannel][i] * visina) / 131070 + visina * LeftVPosition;
        levikanal.lineTo(x,y);
        y= (audiopodatci[Phonon::AudioDataOutput::RightChannel][i] * visina) / 131070 + visina * RightVPosition;
        desnikanal.lineTo(x,y);
        }

    if (UseLeftChannel)
    {
    QPen pen1(QColor::fromRgba(qRgba(LeftChannelColor.toRgb().red(),LeftChannelColor.toRgb().green(),LeftChannelColor.toRgb().blue(),VisualisationOpacitySlider)));
        pen1.setWidth(VisualisationLineWidth);
        painter.setPen(pen1);
        painter.drawPath(levikanal);
    }

    if(UseRightChannel)
    {
    QPen pen2(QColor::fromRgba(qRgba(RightChannelColor.toRgb().red(),RightChannelColor.toRgb().green(),RightChannelColor.toRgb().blue(),VisualisationOpacitySlider)));
        pen2.setWidth(VisualisationLineWidth);
        painter.setPen(pen2);
        painter.drawPath(desnikanal);
    }

    painter.endNativePainting();
    }
}
//------------------------------------------------------------------------------------
void MainWindow::changeEvent(QEvent *event)
{
    if (HideOnMinimize)
    {
    if (event->type() == QEvent::WindowStateChange)
        {
            if (isMinimized())
            {
                ShowHideWindow();
                    event->ignore();
            }
        }
    }
    else
    {
    event->ignore();
    }
}

//------------------------------------------------------------------------------------

void MainWindow::CheckVersion()
{
    //Procitaj i postavi jezik
    QSettings temp_settings("glrp", "Great Little Radio Player");
    temp_settings.beginGroup("MainWindow");
    QString InstalledVersion(temp_settings.value("Version", "1.4.5").toString());//Stara verzija
    temp_settings.endGroup();
    //-----------------------
    QString CurrentVersion(QApplication::applicationVersion());

    if (CurrentVersion != InstalledVersion) //Ako je neka druga verzija, sacuvaj stanice u starom fajlu i zameni novim.
    {
        PathToStationsDir = QDir::homePath() + "/.config/glrp/";
        PathToStationsFile = PathToStationsDir + "stations.csv";

        QFile aFile(PathToStationsFile);
        QFile InstaliraniFajlStanica("/usr/share/glrp/stations.csv");
        if (aFile.exists())
        {
            aFile.rename(PathToStationsFile,PathToStationsFile + ".old");
            QFile oldFile(PathToStationsFile + ".old");
            if (oldFile.exists() && InstaliraniFajlStanica.exists())
            {
                QMessageBox StationsFileChanged;
                StationsFileChanged.setWindowTitle(QString::fromUtf8(LangCheckVersion1.toStdString().c_str()));
                StationsFileChanged.setText(QString::fromUtf8(LangCheckVersion2.toStdString().c_str()) + QString("<b>") + QString::fromUtf8(CurrentVersion.toStdString().c_str()) + QString("</b><br>") + QString::fromUtf8(LangCheckVersion3.toStdString().c_str()) + QString("<b>") + oldFile.fileName() + QString("</b><br>") + QString::fromUtf8(LangCheckVersion4.toStdString().c_str()) + QString("<br>") + QString::fromUtf8(LangCheckVersion5.toStdString().c_str()));
                StationsFileChanged.exec();
            }
        }
    }
}

//------------------------------------------------------------------------------------
void MainWindow::metaDataChanged()
{
try{
   if (!music->metaData(Phonon::TitleMetaData).isEmpty())
       Title = music->metaData(Phonon::TitleMetaData).at(0);

        if (CurrentArtist != Title)
               {
                CurrentArtist = Title;

                if (!music->metaData(Phonon::ArtistMetaData).isEmpty())
                Artist = music->metaData(Phonon::ArtistMetaData).at(0);
                if (!music->metaData(Phonon::AlbumMetaData).isEmpty())
                Album = music->metaData(Phonon::AlbumMetaData).at(0);

                InformSystemAboutSong();
                stateChanged(music->state(),music->state());

                if (!Title.isEmpty())
                setWindowTitle(TITLE + " - " + QString::fromUtf8(Title.toStdString().c_str()));
                else
                    setWindowTitle(TITLE);
               }
    }catch(...){}
}
//------------------------------------------------------------------------------------

void MainWindow::stateChanged(Phonon::State newState, Phonon::State /*oldState*/)
 {
    IMGLabel_StatusString.clear();
    ui->IMGLabel->setText(IMGLabel_StatusString);
    TITLE = QApplication::applicationName() + QString(" - ") + QString::number(tableWidget->rowCount()) + QString::fromUtf8(LangStations.toStdString().c_str());

    if (IconTheme_White)
    myicon = QIcon(":/images/IMG/radio-tray-white-32.png");
    else
        myicon = QIcon(":/images/IMG/radio-white-72.png");

    if(PlayFavorite == "Favorite") IsFavoriteIcon = QString("<img src='" + QString(":/images/IMG/favorite-circle-48.png' width='48' height='48'/>"));
    else IsFavoriteIcon = QString("<img src='" + QString(":/images/IMG/no-favorite-circle-48.png'  width='48' height='48'/> "));

     try{
         if (!music->metaData(Phonon::TitleMetaData).isEmpty())
            Title = music->metaData(Phonon::TitleMetaData).at(0);
         if (!music->metaData(Phonon::ArtistMetaData).isEmpty())
            Artist = music->metaData(Phonon::ArtistMetaData).at(0);
         if (!music->metaData(Phonon::AlbumMetaData).isEmpty())
            Album = music->metaData(Phonon::AlbumMetaData).at(0);

         if (CurrentArtist != Title)
                {
                CurrentArtist = Title;
                InformSystemAboutSong();
                }
        }catch(...){}

    if (!Title.isEmpty())
    setWindowTitle(TITLE + " - " + QString::fromUtf8(Title.toStdString().c_str()));
    else
        setWindowTitle(TITLE);

    trayIcon->setIcon(myicon);

ui->label->setText(QString::fromUtf8(LangPleaseWait.toStdString().c_str())); //Da bi zasigurao da od prvog startovanja kada nema statusa ipak pise nesto.

ui->BufferprogressBar->move(ui->label->x(),ui->label->y() + ui->label->height() - 5);
ui->BufferprogressBar->resize(ui->label->width(),5);

if (!ShowWindowInStyleMode) //CLASSIC MODE
{
    if (newState == Phonon::ErrorState)
    {
             if (music->errorType() == Phonon::FatalError)
             {
                 QMessageBox::warning(this, tr("Fatal Error"),
                 music->errorString());
             }
                 else
                     {
                         QMessageBox::warning(this, tr("Error"),
                         music->errorString());
                     }
             volumeSlider->setEnabled(false);
             volumeSlider2->setEnabled(false);
     }
    else if (newState == Phonon::PlayingState)
    {
        StationNameStatusFont = QString("<font color=#1589FF size=3>");
        IMGLabel_StatusString = QString("<img src='" + QString(":/images/IMG/radio-blue-72.png'/>"));
        if (IconTheme_White)
        myicon = QIcon(":/images/IMG/radio-tray-blue-32.png");
        else
            myicon = QIcon(":/images/IMG/radio-blue-72.png");

        Playing = true;
        //
        QString TableViewLabelText("<table width=100% border=0><tr><td width=20%>" + IsFavoriteIcon + "</td><td width=76% align=center>" + StationNameStatusFont + PlayName + "<br></font><font size=1>" + Title + " / " + Artist + "<br>" + Album + "</font></td></tr></table>");
        ui->label->setText(TableViewLabelText);
        ui->label->setToolTip(QString::fromUtf8(LangFrom.toStdString().c_str()) + PlayCountry + "<br>" + QString::fromUtf8(LangGenre.toStdString().c_str()) + PlayGenre + "<br>" + QString::fromUtf8(SAddress.toStdString().c_str()) + PlayAddress);

        ui->StopButton->setText("");
        StopMenuItem->setText(QString::fromUtf8(LangStopStation.toStdString().c_str()) + PlayName + "'");
        StopMenuItem->setVisible(true);
        ui->actionPause->setEnabled(true);
        ui->actionPause->setText(QString::fromUtf8(LangPause.toStdString().c_str()));
        ui->actionPause->setToolTip(QString::fromUtf8(LangPause.toStdString().c_str()));
        ui->PauseButton->setToolTip(QString::fromUtf8(LangPause.toStdString().c_str()));
        ui->PauseButton->setChecked(false);
        ui->actionPause->setChecked(false);
        PauseMenuItem->setChecked(false);
        PauseMenuItem->setText(QString::fromUtf8(LangPause.toStdString().c_str()));
        PauseMenuItem->setVisible(true);
        ui->BufferprogressBar->setVisible(false);
        volumeSlider->setEnabled(true);
        volumeSlider2->setEnabled(true);
    }
    else if (music->state() == Phonon::StoppedState)
    {
        StationNameStatusFont = QString("<font color=grey size=2>");
        IMGLabel_StatusString = QString("<img src='" + QString(":/images/IMG/radio-white-72.png'/>"));
        if (IconTheme_White)
        myicon = QIcon(":/images/IMG/radio-tray-white-32.png");
        else
            myicon = QIcon(":/images/IMG/radio-white-72.png");

        Playing = false;
        ui->actionPause->setEnabled(false);
        ui->actionPause->setText(QString::fromUtf8(LangPause.toStdString().c_str()));
        ui->actionPause->setToolTip(QString::fromUtf8(LangPause.toStdString().c_str()));
        ui->PauseButton->setToolTip(QString::fromUtf8(LangPause.toStdString().c_str()));
        ui->PauseButton->setChecked(false);
        ui->actionPause->setChecked(false);
        PauseMenuItem->setChecked(false);
        PauseMenuItem->setText(QString::fromUtf8(LangPause.toStdString().c_str()));
        ui->BufferprogressBar->setVisible(false);
        volumeSlider->setEnabled(false);
        volumeSlider2->setEnabled(false);
    }
    else if (music->state() == Phonon::LoadingState)
    {
        StationNameStatusFont = QString("<font color='#99FF00' size=2>");
        IMGLabel_StatusString = QString("<img src='" + QString(":/images/IMG/radio-green-72.png'/>"));
        if (IconTheme_White)
        myicon = QIcon(":/images/IMG/radio-tray-green-32.png");
        else
            myicon = QIcon(":/images/IMG/radio-green-72.png");

        Playing = false;
        ui->label->setText(QString::fromUtf8(LangPleaseWait.toStdString().c_str()));
        ui->actionPause->setEnabled(false);
        ui->actionPause->setText(QString::fromUtf8(LangPause.toStdString().c_str()));
        ui->actionPause->setToolTip(QString::fromUtf8(LangPause.toStdString().c_str()));
        ui->PauseButton->setToolTip(QString::fromUtf8(LangPause.toStdString().c_str()));
        ui->PauseButton->setChecked(false);
        ui->actionPause->setChecked(false);
        PauseMenuItem->setChecked(false);
        PauseMenuItem->setText(QString::fromUtf8(LangPause.toStdString().c_str()));
        PauseMenuItem->setVisible(false);
        volumeSlider->setEnabled(false);
        volumeSlider2->setEnabled(false);
    }
    else if (music->state() == Phonon::BufferingState)
    {
        IMGLabel_StatusString = QString("<img src='" + QString(":/images/IMG/radio-green-72.png'/>"));
        if (IconTheme_White)
        myicon = QIcon(":/images/IMG/radio-tray-green-32.png");
        else
            myicon = QIcon(":/images/IMG/radio-green-72.png");

        Playing = true;
        ui->actionPause->setEnabled(true);
        ui->actionPause->setText(QString::fromUtf8(LangPause.toStdString().c_str()));
        ui->actionPause->setToolTip(QString::fromUtf8(LangPause.toStdString().c_str()));
        ui->PauseButton->setToolTip(QString::fromUtf8(LangPause.toStdString().c_str()));
        ui->actionPause->setChecked(false);
        PauseMenuItem->setChecked(false);
        PauseMenuItem->setText(QString::fromUtf8(LangPause.toStdString().c_str()));
        PauseMenuItem->setVisible(true);
        volumeSlider->setEnabled(true);
        volumeSlider2->setEnabled(true);
    }
    else if (music->state() == Phonon::PausedState)
    {
        StationNameStatusFont = QString("<font color=grey size=2>");
        IMGLabel_StatusString = QString("<img src='" + QString(":/images/IMG/radio-red-72.png'/>"));
        if (IconTheme_White)
        myicon = QIcon(":/images/IMG/radio-tray-red-32.png");
        else
            myicon = QIcon(":/images/IMG/radio-red-72.png");

        Playing = false;
        QString TableViewLabelText("<table width=100% border=0><tr><td width=20%>" + IsFavoriteIcon + "</td><td width=76% align=center>" + StationNameStatusFont + PlayName + "<br><font size=1px>" + QString::fromUtf8(LangPaused.toStdString().c_str()) + "</font></td></tr></table>");
        ui->label->setText(TableViewLabelText);
        ui->actionPause->setEnabled(true);
        ui->actionPause->setText(QString::fromUtf8(LangPaused.toStdString().c_str()));
        ui->actionPause->setToolTip(QString::fromUtf8(LangPlayPaused.toStdString().c_str()));
        ui->PauseButton->setToolTip(QString::fromUtf8(LangPlayPaused.toStdString().c_str()));
        ui->PauseButton->setChecked(true);
        ui->actionPause->setChecked(true);
        PauseMenuItem->setChecked(true);
        PauseMenuItem->setText(QString::fromUtf8(LangPlayPaused.toStdString().c_str()));
        PauseMenuItem->setVisible(true);
        ui->BufferprogressBar->setVisible(false);
        volumeSlider->setEnabled(false);
        volumeSlider2->setEnabled(false);
     }
}
else //STYLE MODE
    {
    if (music->state() == Phonon::PlayingState)
        {
        QString TableViewLabelText("<table width=100% border=0><tr><td width=5%></td><td>" + IsFavoriteIcon + "</td><td align=center>" + PlayName + "<br><font size=1px>" + Title + " / " + Artist + "</font></td><td width=5%></td></tr></table>");
        IMGLabel_StatusString = QString("<img src='" + QString(":/images/IMG/radio-blue-72.png'/>"));
        if (IconTheme_White)
        myicon = QIcon(":/images/IMG/radio-tray-blue-32.png");
        else
            myicon = QIcon(":/images/IMG/radio-blue-72.png");

        ui->label->setText(TableViewLabelText);
        ui->label->setToolTip(QString::fromUtf8(LangFrom.toStdString().c_str()) + PlayCountry + "<br>" + QString::fromUtf8(LangGenre.toStdString().c_str()) + PlayGenre);
        ui->PauseButton->setToolTip(QString::fromUtf8(LangPause.toStdString().c_str()));
        StopMenuItem->setText(QString::fromUtf8(LangStopStation.toStdString().c_str()) + PlayName + "'");
        StopMenuItem->setVisible(true);

        PauseMenuItem->setText(QString::fromUtf8(LangPause.toStdString().c_str()));
        PauseMenuItem->setVisible(true);
        ui->BufferprogressBar->setVisible(false);
        volumeSlider->setEnabled(true);
        volumeSlider2->setEnabled(true);
        }
    else if (music->state() == Phonon::PausedState)
    {
        StationNameStatusFont = QString("<font color=grey size=2>");
        IMGLabel_StatusString = QString("<img src='" + QString(":/images/IMG/radio-red-72.png'/>"));
        if (IconTheme_White)
        myicon = QIcon(":/images/IMG/radio-tray-red-32.png");
        else
            myicon = QIcon(":/images/IMG/radio-red-72.png");

        Playing = false;
        QString TableViewLabelText("<table width=100% border=0><tr><td width=20%>" + IsFavoriteIcon + "</td><td width=76% align=center>" + StationNameStatusFont + PlayName + "<br><font size=1px>" + QString::fromUtf8(LangPaused.toStdString().c_str()) + "</font></td></tr></table>");
        ui->label->setText(TableViewLabelText);
        ui->actionPause->setEnabled(true);
        ui->actionPause->setText(QString::fromUtf8(LangPaused.toStdString().c_str()));
        ui->actionPause->setToolTip(QString::fromUtf8(LangPlayPaused.toStdString().c_str()));
        ui->PauseButton->setToolTip(QString::fromUtf8(LangPlayPaused.toStdString().c_str()));
        PauseMenuItem->setText(QString::fromUtf8(LangPlayPaused.toStdString().c_str()));
        PauseMenuItem->setVisible(true);
        ui->BufferprogressBar->setVisible(false);
        volumeSlider->setEnabled(false);
        volumeSlider2->setEnabled(false);
     }
    else if (music->state() == Phonon::StoppedState)
    {
        StationNameStatusFont = QString("<font color=grey size=2>");
        IMGLabel_StatusString = QString("<img src='" + QString(":/images/IMG/radio-white-72.png'/>"));
        if (IconTheme_White)
        myicon = QIcon(":/images/IMG/radio-tray-white-32.png");
        else
            myicon = QIcon(":/images/IMG/radio-white-72.png");

        Playing = false;
        ui->actionPause->setEnabled(false);
        ui->actionPause->setText(QString::fromUtf8(LangPause.toStdString().c_str()));
        ui->actionPause->setToolTip(QString::fromUtf8(LangPause.toStdString().c_str()));
        PauseMenuItem->setText(QString::fromUtf8(LangPause.toStdString().c_str()));
        ui->BufferprogressBar->setVisible(false);
        volumeSlider->setEnabled(false);
        volumeSlider2->setEnabled(false);
    }
    }

ui->StopButton->setToolTip(QString::fromUtf8(LangStopStation.toStdString().c_str()) + "'" + PlayName + "'");
ui->IMGLabel->setText(IMGLabel_StatusString);//Ucitaj sliku za status
setWindowIcon(myicon);
trayIcon->setIcon(myicon);
ui->PauseButton->move(0,0);
}
//------------------------------------------------------------------------------------
void MainWindow::bufferStatusToTitle(int percentFilled)
{
    if (percentFilled < 100)
    {
    setWindowTitle(TITLE + " - " + QString::fromUtf8(Title.toStdString().c_str()) + " - buffer: " + QString::number(percentFilled) + QString("%"));
    if (ui->BufferprogressBar->y() != ui->label->height()-4)
        {
        ui->BufferprogressBar->move(ui->label->x(),ui->label->height() - 4);
        ui->BufferprogressBar->resize(ui->label->width(),2);
        }
    if (!ui->BufferprogressBar->isVisible())
        ui->BufferprogressBar->setVisible(true);

    ui->BufferprogressBar->setValue(percentFilled);
    }
    else
    {
        if (!Title.isEmpty())
        setWindowTitle(TITLE + " - " + QString::fromUtf8(Title.toStdString().c_str()));
        else
            setWindowTitle(TITLE);

        ui->BufferprogressBar->setVisible(false);
    }
}

//------------------------------------------------------------------------------------
void MainWindow::SystemTray(bool ContextMenuIsVisible)
{
    trayIcon->setContextMenu(NULL);
    trayMenu->clear();

        // load icon
    if (music->state() == Phonon::PlayingState)
            {
        if (IconTheme_White)
            trayIcon->setIcon(QIcon(":/images/IMG/radio-tray-blue-32.png"));
            else
                trayIcon->setIcon(QIcon(":/images/IMG/radio-blue-72.png"));
            }
    else if (music->state() == Phonon::StoppedState)
            {
            if (IconTheme_White)
            trayIcon->setIcon(QIcon(":/images/IMG/radio-tray-white-32.png"));
            else
                trayIcon->setIcon(QIcon(":/images/IMG/radio-white-72.png"));
            }
    else if (music->state() == Phonon::PausedState)
            {
            if (IconTheme_White)
            trayIcon->setIcon(QIcon(":/images/IMG/radio-tray-red-32.png"));
            else
                trayIcon->setIcon(QIcon(":/images/IMG/radio-red-72.png"));
            }
    else if (music->state() == Phonon::BufferingState)
            {
            if (IconTheme_White)
            trayIcon->setIcon(QIcon(":/images/IMG/radio-tray-green-32.png"));
            else
                trayIcon->setIcon(QIcon(":/images/IMG/radio-green-72.png"));
            }

            if (ContextMenuIsVisible)
            {
            //Stringlists and populate
            QStringList StationsList;
            QStringList CategoryList;

            for (int i=0;i<tableWidget->rowCount();i++)
                {
                    StationsList << tableWidget->item(i,0)->text();
                    CategoryList << tableWidget->item(i,2)->text();
                }
            StationsList.sort();
            StationsList.removeDuplicates();
            CategoryList.sort();
            CategoryList.removeDuplicates();

            //Build menus
            QFont serifFont;
            serifFont.setBold(true);

            //By Categoryes
            for (int x = 0; x < CategoryList.count(); x++)
            {
                QMenu *Action = new QMenu(trayMenu);
                Action->setTitle(CategoryList.at(x));
                Action->setIcon(QIcon(":/images/IMG/genre.png"));

                for (int i = 0; i<tableWidget->rowCount(); i++)
                    {
                    if (tableWidget->item(i,2)->text() == CategoryList.at(x))
                        {

                        QAction *StationAction = new QAction(Action);
                        if (tableWidget->item(i,4)->text() == "Favorite")
                        {
                        StationAction->setIcon(QIcon(":/images/IMG/favorite128.png"));
                        StationAction->setFont(serifFont);
                        }
                        else
                           StationAction->setIcon(QIcon(":/images/IMG/note128.png"));

                        StationAction->setText(tableWidget->item(i,0)->text());
                        StationAction->setStatusTip(QString::fromUtf8(LangThisStationComeFrom.toStdString().c_str()));
                        StationAction->setIconVisibleInMenu(true);

                        connect(StationAction, SIGNAL(triggered()), this, SLOT(TrayPlayMusic()));
                        Action->addAction(StationAction);
                        }
                    }
            trayMenu->addMenu(Action);
            }
            trayMenu->addSeparator();

            //-----------About--------------------
            trayMenu->addSeparator();
            About = new QAction(trayMenu);
            About->setText(QString::fromUtf8(LangAbout.toStdString().c_str()));
            About->setIcon(QIcon(":/images/IMG/info.png"));
            trayMenu->addAction(About);
            connect(About, SIGNAL(triggered()), this, SLOT(OpenAboutDialog()));
            trayMenu->addSeparator();
            }

            //By Favorites
            QMenu *FavoriteAction = new QMenu(trayMenu);
            FavoriteAction->setTitle(QString::fromUtf8(LangFavorite.toStdString().c_str()));
            FavoriteAction->setIcon(QIcon(":/images/IMG/favorite.png"));

                for (int i = 0; i<tableWidget->rowCount(); i++)
                    {
                    if (tableWidget->item(i,4)->text() == "Favorite")
                        {
                        QAction *StationAction = new QAction(FavoriteAction);
                        if (tableWidget->item(i,4)->text() == "Favorite")
                            {
                            StationAction->setIcon(QIcon(":/images/IMG/favorite128.png"));

                            StationAction->setText(tableWidget->item(i,0)->text());
                            StationAction->setStatusTip(QString::fromUtf8(LangThisStationComeFrom.toStdString().c_str()));
                            StationAction->setIconVisibleInMenu(true);

                            connect(StationAction, SIGNAL(triggered()), this, SLOT(TrayPlayMusic()));
                            FavoriteAction->addAction(StationAction);
                            }
                        }
                    }
            trayMenu->addSeparator();
            trayMenu->addMenu(FavoriteAction);

            //------------------Stop--------------------
            StopMenuItem = new QAction(trayMenu);
            StopMenuItem->setText(QString::fromUtf8(LangStopStation.toStdString().c_str()) + "'" + PlayName + "'");
            StopMenuItem->setShortcut(QKeySequence(tr("Shift+S")));
            if (music->state() == Phonon::PlayingState)
                StopMenuItem->setVisible(true);
                else
                StopMenuItem->setVisible(false);
            StopMenuItem->setIcon(QIcon(":/images/IMG/disconnect128.png"));
            trayMenu->addAction(StopMenuItem);
            connect(StopMenuItem, SIGNAL(triggered()), this, SLOT(StopRadioStationButton_clicked()));
            //-----------------Pause-------------------------------
            PauseMenuItem = new QAction(trayMenu);
            PauseMenuItem->setText(QString::fromUtf8(LangPause.toStdString().c_str()));
            PauseMenuItem->setShortcut(QKeySequence(tr("Shift+P")));
            if (music->state() == Phonon::PlayingState)
                PauseMenuItem->setVisible(true);
                else
                PauseMenuItem->setVisible(false);
            PauseMenuItem->setIcon(QIcon(":/images/IMG/pause48.png"));
            trayMenu->addAction(PauseMenuItem);
            connect(PauseMenuItem, SIGNAL(triggered()), this, SLOT(Pause()));
            //-----------------Show-------------------------------
            //Show-Hide
            ShowHide = new QAction(trayMenu);
            ShowHide->setShortcut(QKeySequence(tr("Shift+H")));
            if (isVisible()) ShowHide->setText(QString::fromUtf8(LangHidePlayer.toStdString().c_str()));
            else ShowHide->setText(QString::fromUtf8(LangShowPlayer.toStdString().c_str()));
            ShowHide->setIcon(QIcon(":/images/IMG/hide.png"));
            connect(ShowHide, SIGNAL(triggered()),this, SLOT(ShowHideWindow()));
            trayMenu->addAction(ShowHide);
            //-----------------Close-------------------------------
            //Close
            QAction *Close = new QAction(trayMenu);
            Close->setShortcut(QKeySequence(tr("Shift+X")));
            Close->setText(QString::fromUtf8(LangExit.toStdString().c_str()));
            Close->setIcon(QIcon(":/images/IMG/close.png"));
            connect(Close, SIGNAL(triggered()), this, SLOT(Exit()));
            trayMenu->addAction(Close);
            //---------------Set systray---------------------
            // set up and show the system tray icon

            trayIcon->setContextMenu(trayMenu);
            trayIcon->setToolTip(windowTitle());
            trayIcon->show();
            connect(trayIcon, SIGNAL(activated(QSystemTrayIcon::ActivationReason)),this, SLOT(TrayIconActivated(QSystemTrayIcon::ActivationReason)));
}
//------------------------------------------------------------------------------------
void MainWindow::TrayIconActivated(QSystemTrayIcon::ActivationReason razlog)
{
    switch(razlog)
       {
       case QSystemTrayIcon::Trigger:
        {
        ShowHideWindow();
        //ShowMainWindow();
        }
       case QSystemTrayIcon::DoubleClick:
           {
           show();
           }
       default:
            ;
       }
}
//------------------------------------------------------------------------------------
/*void MainWindow::ShowMainWindow()
{
    if (!isHidden())
        {
        hide();
        }
    else
        {
        show();
        }

    if (isVisible()) ShowHide->setText(QString::fromUtf8(LangHidePlayer.toStdString().c_str()));
    else ShowHide->setText(QString::fromUtf8(LangShowPlayer.toStdString().c_str()));
}*/
//------------------------------------------------------------------------------------
void MainWindow::SloveIfStationFileNotExists()
{
    //Provera da li postoji fajl sa jezicima i stanicama i ako ne postoji, pravljenje jednog takvog fajla
    PathToStationsDir = QDir::homePath() + "/.config/glrp/";
    PathToStationsFile = PathToStationsDir + "stations.csv";

try
    {
    //Lokalni dir
    QDir D(PathToStationsDir);
    if (!D.exists()) //Ako ne postoji lokalni dir
    {
    if (D.mkpath(PathToStationsDir))
        {
        //
        }
        else
            {
            QMessageBox msgBoxDir;
            msgBoxDir.setText(QString::fromUtf8(LangError1.toStdString().c_str()) + PathToStationsDir + QString::fromUtf8(LangError1a.toStdString().c_str()));
            msgBoxDir.exec();
            }
    }
    //Lokalni fajl
    QFile F(PathToStationsFile);
    if (!F.exists())//Ako NE postoji lokalni falj
            {
            QFile InstaliraniFajlStanica("/usr/share/glrp/stations.csv");
            if (InstaliraniFajlStanica.exists())//Ako postoji instalirani fajl
                {
                F.copy(InstaliraniFajlStanica.fileName(),PathToStationsFile);
                }
                else
                    {//Ako NE postoji instalirani fajl
                    QFile PortableStationsFile(QApplication::applicationDirPath() + QDir::separator() + "stations.csv"); //Napravi varijantu za PORTABLE koriscenje
                    if (PortableStationsFile.exists())
                    {
                        PathToStationsFile = PortableStationsFile.fileName();
                        QApplication::setApplicationName("Great Little Radio Player - PORTABLE");
                    }
                    else
                    {
                        QMessageBox msgBoxFile;
                        msgBoxFile.setText(QString::fromUtf8(LangError2.toStdString().c_str()) + PathToStationsFile + QString::fromUtf8(LangError1a.toStdString().c_str()));
                        msgBoxFile.exec();
                    }
                    }
            }
    }
    catch(...){}
}
//------------------------------------------------------------------------------------
void MainWindow::SaveStations()
{
    QFile SaveFile(PathToStationsFile);
    if (SaveFile.exists())
    {
             if(SaveFile.open(QIODevice::WriteOnly))
             {
                 QTextStream ts(&SaveFile);
                 QStringList strList;
                 for( int r = 0; r < tableWidget->rowCount(); ++r )
                    {
                     strList.clear();
                     for( int c = 0; c < tableWidget->columnCount(); ++c )
                        {
                        strList << "\"" + tableWidget->item(r, c)->text() + "\"";
                        }
                    ts << strList.join(",") + "\n";
                    }
                SaveFile.close();
             }
    }
}
//------------------------------------------------------------------------------------
void MainWindow::Load_stations(QString PathToStationsFile)
{
    QFile OpenFile(PathToStationsFile);
    if (OpenFile.exists())
    {
            if(OpenFile.open(QIODevice::ReadOnly))
                {
                QTextStream ts( &OpenFile );
                QList<QStringList> list;
                int row = 0, col = 0;

                while( !ts.atEnd() )
                    {
                    list << ts.readLine().split( "," );
                    }
                OpenFile.close();

                tableWidget->setRowCount( list.count() );
                tableWidget->setColumnCount( list[0].count() );

                tableWidget->setUpdatesEnabled( false );
                foreach( QStringList l, list )
                {
                    foreach( QString str, l )
                    {

                        if( str.endsWith( '"' ) ) str.chop(1);
                        if( str.startsWith( '"' ) ) str.remove(0,1);
                        tableWidget->setItem( row, col++, new QTableWidgetItem( str ));
                    }
                    row++; col=0;
                }
                tableWidget->setUpdatesEnabled( true );
            }
       }
}


//------------------------------------------------------------------------------------
void MainWindow::RefreshGenreCountryList(QString arg1)
{
        ui->GenreCountryStringTreeWidget->clear();
        ui->GenreCountryStringTreeWidget->setColumnCount(2);
        ui->GenreCountryStringTreeWidget->setColumnWidth(0,170);
        ui->GenreCountryStringTreeWidget->setColumnWidth(1,50);
        ui->GenreCountryStringTreeWidget->header()->hide();

        QStringList GenreCountryStringList;
        GenreCountryStringList.clear();

        int row = tableWidget->rowCount();
        //---------------------------
        for (int n = 0; n < row; n++)
            {
            if (arg1 == "Country")
                {
                GenreCountryStringList << tableWidget->item(n,3)->text();
                }
            else if (arg1 == "Genre")
                {
                GenreCountryStringList << tableWidget->item(n,2)->text();
                }
            }
        GenreCountryStringList.sort();
        GenreCountryStringList.removeDuplicates();
        //---------------------------
        if (arg1 == "Genre")
        {
            //All
            QTreeWidgetItem * AllItem = new QTreeWidgetItem(ui->GenreCountryStringTreeWidget);
            AllItem->setText(0,QString("All Genres"));
            AllItem->setIcon(0,QIcon(":/images/IMG/genre-light.png"));

            //if (!ShowWindowInStyleMode)
            //{
            QFont font;
            font.setBold(true);
            //font.setPointSize(10);
            AllItem->setFont(0,font);
            //}
            //Fin All
        for (int i = 0; i < GenreCountryStringList.count(); i++)
            {
            QTreeWidgetItem * GenreItem = new QTreeWidgetItem(ui->GenreCountryStringTreeWidget);
            GenreItem->setText(0,QString(GenreCountryStringList.at(i)));
            GenreItem->setIcon(0,QIcon(":/images/IMG/genre-light.png"));

            if (!ShowWindowInStyleMode)
            {
            QBrush crna(QColor(0,0,0,200));// crna
            GenreItem->setForeground(0,crna);
            }
            //---------------------------
            QStringList CountryStringList;
            CountryStringList.clear();
            for (int s = 0; s < row; s++)
                {
                if (tableWidget->item(s,2)->text() == QString(GenreCountryStringList.at(i)))
                    {
                    CountryStringList << tableWidget->item(s,3)->text();
                    }
                }
            CountryStringList.sort();
            CountryStringList.removeDuplicates();

            int all_stations_in_category_count = 0;
            for (int l = 0; l < CountryStringList.count(); l++)
                {
                QTreeWidgetItem * StationNameItem = new QTreeWidgetItem(GenreItem);
                StationNameItem->setText(0,CountryStringList.at(l));
                StationNameItem->setIcon(0,QIcon(":/images/IMG/flag22.png"));


                QBrush tamnosiva(QColor(139,139,131,255));//tamnije siva

                if (!ShowWindowInStyleMode)
                {
                StationNameItem->setForeground(0,tamnosiva);
                }
                int stationcount = 0;
                for (int r = 0; r < row; r++)
                    {
                    if (QString(GenreCountryStringList.at(i)) == tableWidget->item(r,2)->text())
                        {
                        if (QString(CountryStringList.at(l)) == tableWidget->item(r,3)->text())
                            {
                            ++stationcount;
                            ++all_stations_in_category_count;
                            }
                        }
                    }
                StationNameItem->setText(1,QString("%1").arg(stationcount));
                StationNameItem->setTextAlignment(1,Qt::AlignRight | Qt::AlignVCenter);
                if (!ShowWindowInStyleMode)
                {
                StationNameItem->setForeground(1,tamnosiva);
                }

                GenreItem->setText(1,QString(QString("%1").arg(all_stations_in_category_count)));
                GenreItem->setTextAlignment(1,Qt::AlignRight | Qt::AlignVCenter);

                if (!ShowWindowInStyleMode)
                {
                QFont Genrefont;
                Genrefont.setBold(true);
                GenreItem->setFont(1,Genrefont);
                QBrush blagosiva(QColor(105,105,105,255));//blago siva
                GenreItem->setForeground(1,blagosiva);
                }
                GenreItem->addChild(StationNameItem);
                }
            }
        }
        //---------------------------
        if (arg1 == "Country")
        {
            //All
            QTreeWidgetItem * AllItem = new QTreeWidgetItem(ui->GenreCountryStringTreeWidget);
            AllItem->setText(0,QString("All Countries"));
            AllItem->setIcon(0,QIcon(":/images/IMG/flag-light.png"));

            QFont font;
            font.setBold(true);
            AllItem->setFont(0,font);
            //Fin All

        for (int i = 0; i < GenreCountryStringList.count(); i++)
            {
            QTreeWidgetItem * GenreItem = new QTreeWidgetItem(ui->GenreCountryStringTreeWidget);
            GenreItem->setText(0,QString(GenreCountryStringList.at(i)));
            GenreItem->setIcon(0,QIcon(":/images/IMG/flag-light.png"));
            QBrush crna(QColor(0,0,0,200));// crna
            GenreItem->setForeground(0,crna);
            //---------------------------
            QStringList GenreStringList;
            GenreStringList.clear();
            for (int s = 0; s < row; s++)
                {
                if (tableWidget->item(s,3)->text() == QString(GenreCountryStringList.at(i)))
                    {

                    GenreStringList << tableWidget->item(s,2)->text();

                    }
                }
            GenreStringList.sort();
            GenreStringList.removeDuplicates();
            int all_stations_in_category_count = 0;
            for (int l = 0; l < GenreStringList.count(); l++)
                {
                QTreeWidgetItem * StationNameItem = new QTreeWidgetItem(GenreItem);
                StationNameItem->setText(0,QString(GenreStringList.at(l)));
                StationNameItem->setIcon(0,QIcon(":/images/IMG/genre22.png"));


                QBrush tamnosiva(QColor(139,139,131,255));//tamnije siva
                StationNameItem->setForeground(0,tamnosiva);


                int stationcount = 0;
                for (int r = 0; r < row; r++)
                    {

                    if (QString(GenreCountryStringList.at(i)) == tableWidget->item(r,3)->text())
                        {
                        if (QString(GenreStringList.at(l)) == tableWidget->item(r,2)->text())
                            {
                            ++stationcount;
                            ++all_stations_in_category_count;
                            }
                        }
                    }
                StationNameItem->setText(1,QString("%1").arg(stationcount));
                StationNameItem->setTextAlignment(1,Qt::AlignRight | Qt::AlignVCenter);
                StationNameItem->setForeground(1,tamnosiva);

                GenreItem->setText(1,QString(QString("%1").arg(all_stations_in_category_count)));
                GenreItem->setTextAlignment(1,Qt::AlignRight | Qt::AlignVCenter);
                QFont Genrefont;
                Genrefont.setBold(true);
                GenreItem->setFont(1,Genrefont);
                QBrush blagosiva(QColor(105,105,105,255));//blago siva
                GenreItem->setForeground(1,blagosiva);
                GenreItem->addChild(StationNameItem);
                }
            }
        }

    ui->StationslistWidget->clear();

    setWindowTitle(QApplication::applicationName() + QString(" - ") + QString::number(tableWidget->rowCount()) + QString::fromUtf8(LangStations.toStdString().c_str()));

    ExpandCollapse();
}
//------------------------------------------------------------------------------------
void MainWindow::GenreCountryItemClicked(QTreeWidgetItem *item, int /*column*/)
{
    ui->StationslistWidget->clear();

        if (item->parent()) //Ukoliko je selektiran neki child item
        {
            if (StatusCountry)
            {
            for (int i = 0; i < tableWidget->rowCount(); i++)
                {
                if ((item->parent()->text(0) == tableWidget->item(i,3)->text()) && item->text(0) == tableWidget->item(i,2)->text())
                    {
                    if (tableWidget->item(i,4)->text() == "Favorite")
                        {
                        QListWidgetItem *itemX;
                        itemX = new QListWidgetItem(QIcon(":/images/IMG/favorite128.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::Type);
                        if (ui->StationslistWidget->viewMode() == QListView::IconMode)
                        itemX->setTextAlignment(Qt::AlignCenter);
                        else
                           itemX->setTextAlignment(Qt::AlignJustify | Qt::AlignVCenter);
                        itemX->setToolTip(QString::fromUtf8(SName.toStdString().c_str()) + tableWidget->item(i,0)->text() + "<br>" + QString::fromUtf8(SAddress.toStdString().c_str()) + tableWidget->item(i,1)->text() + "<br>" + QString::fromUtf8(SGenre.toStdString().c_str()) + tableWidget->item(i,2)->text() + "<br>" + QString::fromUtf8(SRegion.toStdString().c_str()) + tableWidget->item(i,3)->text());
                        }
                    else
                        {
                        QListWidgetItem *itemX;
                        itemX = new QListWidgetItem(QIcon(":/images/IMG/note128.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::Type);
                        if (ui->StationslistWidget->viewMode() == QListView::IconMode)
                        itemX->setTextAlignment(Qt::AlignCenter);
                        else
                           itemX->setTextAlignment(Qt::AlignJustify | Qt::AlignVCenter);
                        itemX->setToolTip(QString::fromUtf8(SName.toStdString().c_str()) + tableWidget->item(i,0)->text() + "<br>" + QString::fromUtf8(SAddress.toStdString().c_str()) + tableWidget->item(i,1)->text() + "<br>" + QString::fromUtf8(SGenre.toStdString().c_str()) + tableWidget->item(i,2)->text() + "<br>" + QString::fromUtf8(SRegion.toStdString().c_str()) + tableWidget->item(i,3)->text());
                        }
                    }
                }
            }
            else if (StatusGenre)
                {
                for (int i = 0; i < tableWidget->rowCount(); i++)
                    {
                    if ((item->parent()->text(0) == tableWidget->item(i,2)->text()) && item->text(0) == tableWidget->item(i,3)->text())
                        {
                        if (tableWidget->item(i,4)->text() == "Favorite")
                            {
                            QListWidgetItem *itemX;
                            itemX = new QListWidgetItem(QIcon(":/images/IMG/favorite128.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::Type);
                            if (ui->StationslistWidget->viewMode() == QListView::IconMode)
                            itemX->setTextAlignment(Qt::AlignCenter);
                            else
                               itemX->setTextAlignment(Qt::AlignJustify | Qt::AlignVCenter);
                            itemX->setToolTip(QString::fromUtf8(SName.toStdString().c_str()) + tableWidget->item(i,0)->text() + "<br>" + QString::fromUtf8(SAddress.toStdString().c_str()) + tableWidget->item(i,1)->text() + "<br>" + QString::fromUtf8(SGenre.toStdString().c_str()) + tableWidget->item(i,2)->text() + "<br>" + QString::fromUtf8(SRegion.toStdString().c_str()) + tableWidget->item(i,3)->text());
                            }
                        else
                            {
                            QListWidgetItem *itemX;
                            itemX = new QListWidgetItem(QIcon(":/images/IMG/note128.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::Type);
                            if (ui->StationslistWidget->viewMode() == QListView::IconMode)
                            itemX->setTextAlignment(Qt::AlignCenter);
                            else
                               itemX->setTextAlignment(Qt::AlignJustify | Qt::AlignVCenter);
                            itemX->setToolTip(QString::fromUtf8(SName.toStdString().c_str()) + tableWidget->item(i,0)->text() + "<br>" + QString::fromUtf8(SAddress.toStdString().c_str()) + tableWidget->item(i,1)->text() + "<br>" + QString::fromUtf8(SGenre.toStdString().c_str()) + tableWidget->item(i,2)->text() + "<br>" + QString::fromUtf8(SRegion.toStdString().c_str()) + tableWidget->item(i,3)->text());
                            }
                        }
                    }
                }
        }
        else //Ukoliko je selektiran neki glavni item
            {
            if ((item->text(0) == "All Countries") || (item->text(0) == "All Genres"))
                {
                for (int i = 0; i < tableWidget->rowCount(); i++)
                    {
                    if (tableWidget->item(i,4)->text() == "Favorite")
                        {
                        QListWidgetItem *itemX;
                        itemX = new QListWidgetItem(QIcon(":/images/IMG/favorite128.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::Type);
                        if (ui->StationslistWidget->viewMode() == QListView::IconMode)
                        itemX->setTextAlignment(Qt::AlignCenter);
                        else
                           itemX->setTextAlignment(Qt::AlignJustify | Qt::AlignVCenter);
                        itemX->setToolTip(QString::fromUtf8(SName.toStdString().c_str()) + tableWidget->item(i,0)->text() + "<br>" + QString::fromUtf8(SAddress.toStdString().c_str()) + tableWidget->item(i,1)->text() + "<br>" + QString::fromUtf8(SGenre.toStdString().c_str()) + tableWidget->item(i,2)->text() + "<br>" + QString::fromUtf8(SRegion.toStdString().c_str()) + tableWidget->item(i,3)->text());
                        }
                    else
                        {
                        QListWidgetItem *itemX;
                        itemX = new QListWidgetItem(QIcon(":/images/IMG/note128.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::Type);
                        if (ui->StationslistWidget->viewMode() == QListView::IconMode)
                        itemX->setTextAlignment(Qt::AlignCenter);
                        else
                           itemX->setTextAlignment(Qt::AlignJustify | Qt::AlignVCenter);
                        itemX->setToolTip(QString::fromUtf8(SName.toStdString().c_str()) + tableWidget->item(i,0)->text() + "<br>" + QString::fromUtf8(SAddress.toStdString().c_str()) + tableWidget->item(i,1)->text() + "<br>" + QString::fromUtf8(SGenre.toStdString().c_str()) + tableWidget->item(i,2)->text() + "<br>" + QString::fromUtf8(SRegion.toStdString().c_str()) + tableWidget->item(i,3)->text());
                        }

                    }
                }
            else
                {
                if (StatusCountry)
                    {
                    for (int i = 0; i < tableWidget->rowCount(); i++)
                        {
                        if (item->text(0) == tableWidget->item(i,3)->text())
                            {
                            if (tableWidget->item(i,4)->text() == "Favorite")
                                {
                                QListWidgetItem *itemX;
                                itemX = new QListWidgetItem(QIcon(":/images/IMG/favorite128.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::Type);
                                if (ui->StationslistWidget->viewMode() == QListView::IconMode)
                                itemX->setTextAlignment(Qt::AlignCenter);
                                else
                                   itemX->setTextAlignment(Qt::AlignJustify | Qt::AlignVCenter);
                                itemX->setToolTip(QString::fromUtf8(SName.toStdString().c_str()) + tableWidget->item(i,0)->text() + "<br>" + QString::fromUtf8(SAddress.toStdString().c_str()) + tableWidget->item(i,1)->text() + "<br>" + QString::fromUtf8(SGenre.toStdString().c_str()) + tableWidget->item(i,2)->text() + "<br>" + QString::fromUtf8(SRegion.toStdString().c_str()) + tableWidget->item(i,3)->text());
                                }
                            else
                                {
                                QListWidgetItem *itemX;
                                itemX = new QListWidgetItem(QIcon(":/images/IMG/note128.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::Type);
                                if (ui->StationslistWidget->viewMode() == QListView::IconMode)
                                itemX->setTextAlignment(Qt::AlignCenter);
                                else
                                   itemX->setTextAlignment(Qt::AlignJustify | Qt::AlignVCenter);
                                itemX->setToolTip(QString::fromUtf8(SName.toStdString().c_str()) + tableWidget->item(i,0)->text() + "<br>" + QString::fromUtf8(SAddress.toStdString().c_str()) + tableWidget->item(i,1)->text() + "<br>" + QString::fromUtf8(SGenre.toStdString().c_str()) + tableWidget->item(i,2)->text() + "<br>" + QString::fromUtf8(SRegion.toStdString().c_str()) + tableWidget->item(i,3)->text());
                                }
                            }
                        }
                    }
                    else if (StatusGenre)
                        {
                        for (int i = 0; i < tableWidget->rowCount(); i++)
                            {
                            if (item->text(0) == tableWidget->item(i,2)->text())
                                {
                                if (tableWidget->item(i,4)->text() == "Favorite")
                                    {
                                    QListWidgetItem *itemX;
                                    itemX = new QListWidgetItem(QIcon(":/images/IMG/favorite128.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::Type);
                                    if (ui->StationslistWidget->viewMode() == QListView::IconMode)
                                    itemX->setTextAlignment(Qt::AlignCenter);
                                    else
                                       itemX->setTextAlignment(Qt::AlignJustify | Qt::AlignVCenter);
                                    itemX->setToolTip(QString::fromUtf8(SName.toStdString().c_str()) + tableWidget->item(i,0)->text() + "<br>" + QString::fromUtf8(SAddress.toStdString().c_str()) + tableWidget->item(i,1)->text() + "<br>" + QString::fromUtf8(SGenre.toStdString().c_str()) + tableWidget->item(i,2)->text() + "<br>" + QString::fromUtf8(SRegion.toStdString().c_str()) + tableWidget->item(i,3)->text());
                                    }
                                else
                                    {
                                    QListWidgetItem *itemX;
                                    itemX = new QListWidgetItem(QIcon(":/images/IMG/note128.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::Type);
                                    if (ui->StationslistWidget->viewMode() == QListView::IconMode)
                                    itemX->setTextAlignment(Qt::AlignCenter);
                                    else
                                       itemX->setTextAlignment(Qt::AlignJustify | Qt::AlignVCenter);
                                    itemX->setToolTip(QString::fromUtf8(SName.toStdString().c_str()) + tableWidget->item(i,0)->text() + "<br>" + QString::fromUtf8(SAddress.toStdString().c_str()) + tableWidget->item(i,1)->text() + "<br>" + QString::fromUtf8(SGenre.toStdString().c_str()) + tableWidget->item(i,2)->text() + "<br>" + QString::fromUtf8(SRegion.toStdString().c_str()) + tableWidget->item(i,3)->text());
                                    }
                                }
                            }
                        }
                }
            }
    ui->StationslistWidget->sortItems(Qt::AscendingOrder);

    ui->StationslistWidget->scrollToTop();
}

//------------------------------------------------------------------------------------

void MainWindow::ShowContextMenu(const QPoint& pos) // this is a slot
{
    QMenu *menu = new QMenu;

    FavoriteOnOffMenuItem = new QAction(menu);
    FavoriteOnOffMenuItem->setText(QString::fromUtf8(LangFavorite.toStdString().c_str()) + QString(" [on/off]"));
    FavoriteOnOffMenuItem->setVisible(true);
    FavoriteOnOffMenuItem->setIcon(QIcon(":/images/IMG/favorite.png"));
    connect(FavoriteOnOffMenuItem, SIGNAL(triggered()), this, SLOT(SetOrRemoveFavorite()));

    DeleteMenuItem = new QAction(menu);
    DeleteMenuItem->setText(QString::fromUtf8(LangDelete.toStdString().c_str()));
    DeleteMenuItem->setVisible(true);
    DeleteMenuItem->setIcon(QIcon(":/images/IMG/delete48.png"));
    connect(DeleteMenuItem, SIGNAL(triggered()), this, SLOT(DeleteStation()));

    menu->addAction(PauseMenuItem);
    menu->addAction(FavoriteOnOffMenuItem);
    menu->addMenu(ui->menuStation_View);
    menu->addAction(DeleteMenuItem);

    if (ShowWindowInStyleMode)
    {
    QFile File("/usr/share/glrp/styles/" + StyleName);
    if (File.exists())
        {
        File.open(QFile::ReadOnly);
        QString StyleSheet = QString(File.readAll());
        menu->setStyleSheet(StyleSheet);
        }
    }

    menu->exec(ui->StationslistWidget->mapToGlobal(pos));
    SaveStations();
}
//------------------------------------------------------------------------------------
void MainWindow::SetOrRemoveFavorite()
{
    try
        {
        QString S(ui->StationslistWidget->selectedItems().takeAt(0)->text());

        for (int i = 0; i < tableWidget->rowCount(); i++)
        {
            if (S == tableWidget->item(i,0)->text())
                {
                if (tableWidget->item(i,4)->text() == "Favorite")
                    {
                    tableWidget->item(i,4)->setText("");
                    ui->StationslistWidget->selectedItems().takeAt(0)->setIcon(QIcon(":/images/IMG/note128.png"));
                    }
                else
                    {
                    tableWidget->item(i,4)->setText("Favorite");
                    ui->StationslistWidget->selectedItems().takeAt(0)->setIcon(QIcon(":/images/IMG/favorite128.png"));
                    }
                break;
                }

        }
        }catch(...){}
}
//------------------------------------------------------------------------------------
void MainWindow::DeleteStation()
{
    QString S(ui->StationslistWidget->selectedItems().takeAt(0)->text());

        QMessageBox msgBox;
        msgBox.setText(QString::fromUtf8(LangDeleteInfo1.toStdString().c_str()) + "<b>'" + S + "'</b>" + QString::fromUtf8(LangDeleteInfo1a.toStdString().c_str()));
         msgBox.setInformativeText(QString::fromUtf8(LangDeleteInfo1b.toStdString().c_str()));
         msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel);
         msgBox.setDefaultButton(QMessageBox::Cancel);
         msgBox.setIcon(QMessageBox::Warning);
         int ret = msgBox.exec();

         switch (ret) {
           case QMessageBox::Yes:
                {
                    try
                    {
                    for (int i = 0; i < tableWidget->rowCount(); i++)
                    {
                         if (S == tableWidget->item(i,0)->text())
                             {
                             tableWidget->removeRow(i);
                             //Osvezi klikom na neko dugme
                             RefreshGenreCountryList("Genre");
                             ShowFavorites();
                             break;
                             }
                     }
                     }catch(...){}
                }
               break;
           case QMessageBox::No:
               {
                 QMessageBox msgBox1;
                 msgBox1.setText(QString::fromUtf8(LangDeleteInfo2.toStdString().c_str()));
                 msgBox1.setInformativeText(QString::fromUtf8(LangDeleteInfo2a.toStdString().c_str()) + "<b>'" + S + "'</b>" + QString::fromUtf8(LangDeleteInfo2b.toStdString().c_str()));
                 msgBox1.setStandardButtons(QMessageBox::Ok);
                 msgBox1.setDefaultButton(QMessageBox::Ok);
                 msgBox1.setIcon(QMessageBox::Information);
                 msgBox1.exec();
                }
               break;
           case QMessageBox::Cancel:
               break;
           default:
               break;
         }
}
//------------------------------------------------------------------------------------
void MainWindow::TrayPlayMusic()
{
    ui->StationslistWidget->selectionModel()->reset();
    ui->StationslistWidget->repaint();

        QAction *A;
        QObject *Y = QObject::sender();
        A = qobject_cast<QAction *>(Y);
        QString StationName(A->text());

        try
        {
        QString S(StationName);

        for (int i = 0; i < tableWidget->rowCount(); i++)
        {
            if (S == tableWidget->item(i,0)->text())
                {
                PlayName = tableWidget->item(i,0)->text();
                PlayAddress = tableWidget->item(i,1)->text();
                PlayCountry = tableWidget->item(i,3)->text();
                PlayGenre = tableWidget->item(i,2)->text();
                PlayFavorite = tableWidget->item(i,4)->text();
                break;
                }
        }
        PlayMusic(PlayName,PlayAddress);

        for (int m = 0; m < ui->StationslistWidget->count(); m++)
        {
            if (ui->StationslistWidget->item(m)->text() == PlayName)
                ui->StationslistWidget->item(m)->setSelected(true);
        }


        //CheckIfStationRunning();
        ui->widget->show();
        }catch(...){}
}

//------------------------------------------------------------------------------------

void MainWindow::AddNewStationFunction(QString StationName, QString StationAddress, QString StationGenre, QString StationCountry, QString FavoriteONOFF)
{


    if ((!StationName.isEmpty()) && (!StationAddress.isEmpty()) && (!StationGenre.isEmpty()) && (!StationCountry.isEmpty()))
        {
            try
            {
            int row = tableWidget->rowCount();
            tableWidget->insertRow(row);

            QTableWidgetItem *Name = new QTableWidgetItem;
            Name->setText(StationName);

            QTableWidgetItem *Address = new QTableWidgetItem;
            Address->setText(StationAddress);

            QTableWidgetItem *Genre = new QTableWidgetItem;
            Genre->setText(StationGenre);

            QTableWidgetItem *Country = new QTableWidgetItem;
            Country->setText(StationCountry);

            QTableWidgetItem *Favorite = new QTableWidgetItem;
            Favorite->setText(FavoriteONOFF);

            QTableWidgetItem *Item5 = new QTableWidgetItem;
            Item5->setText("");

            QTableWidgetItem *Item6 = new QTableWidgetItem;
            Item6->setText("");

            tableWidget->setItem(row, 0, Name);
            tableWidget->setItem(row, 1, Address);
            tableWidget->setItem(row, 2, Genre);
            tableWidget->setItem(row, 3, Country);
            tableWidget->setItem(row, 4, Favorite);
            tableWidget->setItem(row, 5, Item5);
            tableWidget->setItem(row, 6, Item6);

            QMessageBox reactMsgBox;
            reactMsgBox.setText(QString::fromUtf8(LangStationSaved1.toStdString().c_str()));
            QString s(StationAddress);
            QString startaddress(s.mid(0,15));
            reactMsgBox.setInformativeText(QString::fromUtf8(SName.toStdString().c_str()) + "\t" + StationName + "\n" + QString::fromUtf8(SAddress.toStdString().c_str()) + "\t" + startaddress + "..." + "\n\n" + QString::fromUtf8(LangStationSaved1a.toStdString().c_str()));
            reactMsgBox.setIcon(QMessageBox::Information);
            reactMsgBox.exec();
            }
            catch(...){}
        }
        if (StatusCountry)
            RefreshGenreCountryList("Country");
        else if (StatusGenre)
            RefreshGenreCountryList("Genre");

        SystemTray(ShowStationsSystemTray);
        ShowFavorites();
}
//------------------------------------------------------------------------------------
void MainWindow::AddStationsOneByOneFunction(QString StationName, QString StationAddress, QString StationGenre, QString StationCountry, QString FavoriteONOFF)
{
    if ((!StationName.isEmpty()) && (!StationAddress.isEmpty()) && (!StationGenre.isEmpty()) && (!StationCountry.isEmpty()))
        {
            try
            {
            int row = tableWidget->rowCount();
            tableWidget->insertRow(row);

            QTableWidgetItem *Name = new QTableWidgetItem;
            Name->setText(StationName);

            QTableWidgetItem *Address = new QTableWidgetItem;
            Address->setText(StationAddress);

            QTableWidgetItem *Genre = new QTableWidgetItem;
            Genre->setText(StationGenre);

            QTableWidgetItem *Country = new QTableWidgetItem;
            Country->setText(StationCountry);

            QTableWidgetItem *Favorite = new QTableWidgetItem;
            Favorite->setText(FavoriteONOFF);

            QTableWidgetItem *Item5 = new QTableWidgetItem;
            Item5->setText("");

            QTableWidgetItem *Item6 = new QTableWidgetItem;
            Item6->setText("");

            tableWidget->setItem(row, 0, Name);
            tableWidget->setItem(row, 1, Address);
            tableWidget->setItem(row, 2, Genre);
            tableWidget->setItem(row, 3, Country);
            tableWidget->setItem(row, 4, Favorite);
            tableWidget->setItem(row, 5, Item5);
            tableWidget->setItem(row, 6, Item6);
            }
            catch(...){}
        }
        if (StatusCountry)
            RefreshGenreCountryList("Country");
        else if (StatusGenre)
            RefreshGenreCountryList("Genre");

        SystemTray(ShowStationsSystemTray);
}
//------------------------------------------------------------------------------------
void MainWindow::StopRadioStationButton_clicked()
{
       music->stop();

       ui->widget->hide();
       setWindowTitle(QApplication::applicationName());
       StopMenuItem->setVisible(false);
       PauseMenuItem->setVisible(false);

       ui->StationslistWidget->selectionModel()->reset();

}
//------------------------------------------------------------------------------------
void MainWindow::StationClicked(QListWidgetItem *item)
{
    try
        {
        QString S(item->text());

        for (int i = 0; i < tableWidget->rowCount(); i++)
        {
            if (S == tableWidget->item(i,0)->text())
                {
                PlayName = tableWidget->item(i,0)->text();
                PlayAddress = tableWidget->item(i,1)->text();
                PlayCountry = tableWidget->item(i,3)->text();
                PlayGenre = tableWidget->item(i,2)->text();
                PlayFavorite = tableWidget->item(i,4)->text();
                break;
                }
        }
        PlayMusic(PlayName,PlayAddress);
        StopMenuItem->setText(QString::fromUtf8(LangStopStation.toStdString().c_str()) + "'" + PlayName + "'");
        StopMenuItem->setVisible(true);
        //CheckIfStationRunning();

        ui->widget->show();
        }catch(...){}
}
//------------------------------------------------------------------------------------
void MainWindow::PlayMusic(QString /*StationName*/, QString StationAddress)
{
    Phonon::BackendCapabilities::availableAudioOutputDevices();
    try
    {
    music->setCurrentSource(Phonon::MediaSource(StationAddress));
    music->play();
    }catch(...){}
}

//------------------------------------------------------------------------------------

void MainWindow::Pause()
{
    if (music->state() == Phonon::PlayingState)
    {
    music->pause();
    ui->actionPause->setChecked(true);
    ui->PauseButton->setChecked(true);
    }
    else
    {
        music->play();
        ui->actionPause->setChecked(false);
        ui->PauseButton->setChecked(false);
    }
}
//------------------------------------------------------------------------------------
void MainWindow::InformSystemAboutSong()
{
    if ((trayIcon->supportsMessages()) && (ShowSystemTrayMessage))
    {
    if (!music->metaData(Phonon::TitleMetaData).isEmpty())
        {
            trayIcon->showMessage(Artist, Title, QSystemTrayIcon::NoIcon,5000);
        }
    }
}

//------------------------------------------------------------------------------------
void MainWindow::SortStationsByCountry()
{
    RefreshGenreCountryList("Country");
    StatusGenre = false;
    StatusCountry = true;
}
//------------------------------------------------------------------------------------
void MainWindow::SortStationsByGenre()
{
    RefreshGenreCountryList("Genre");
    StatusCountry = false;
    StatusGenre = true;
}
//------------------------------------------------------------------------------------
void MainWindow::ShowFavorites()
{
    ui->StationslistWidget->clear();
        for (int i = 0; i < tableWidget->rowCount(); i++)
            {
            if (tableWidget->item(i,4)->text() == "Favorite")
                {
                QListWidgetItem *itemX;
                itemX = new QListWidgetItem(QIcon(":/images/IMG/favorite128.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::Type);
                if (ui->StationslistWidget->viewMode() == QListView::IconMode)
                    {
                    itemX->setTextAlignment(Qt::AlignCenter);
                    ui->StationslistWidget->setTextElideMode(Qt::ElideRight);
                    }
                else
                   {
                    itemX->setTextAlignment(Qt::AlignJustify | Qt::AlignVCenter);
                    ui->StationslistWidget->setTextElideMode(Qt::ElideNone);
                    }
                itemX->setToolTip(QString::fromUtf8(SName.toStdString().c_str()) + tableWidget->item(i,0)->text() + "<br>" + QString::fromUtf8(SAddress.toStdString().c_str()) + tableWidget->item(i,1)->text() + "<br>" + QString::fromUtf8(SGenre.toStdString().c_str()) + tableWidget->item(i,2)->text() + "<br>" + QString::fromUtf8(SRegion.toStdString().c_str()) + tableWidget->item(i,3)->text());
                }
            }
ui->StationslistWidget->scrollToTop();
}
//------------------------------------------------------------------------------------
void MainWindow::ShowHideWindow()
{


    if ((!isHidden()) || (!Qt::WindowMinimized))
        {
            hide();
        }
    else
        {
        setWindowState(Qt::WindowNoState);
        show();
        }
//Postavljanje statusa vidljivosti u meni za prikazivanje tj sakrivanje playera
if (isVisible()) ShowHide->setText(QString::fromUtf8(LangHidePlayer.toStdString().c_str()));
else ShowHide->setText(QString::fromUtf8(LangShowPlayer.toStdString().c_str()));

if (!trayIcon->isVisible())trayIcon->setVisible(true);

SystemTray(ShowStationsSystemTray);
}
//------------------------------------------------------------------------------------

void MainWindow::FilterStations()
{
    QWidget *SearchWidget = new QWidget(this);
    SearchWidget->setObjectName("SearchWidget");
    SearchWidget->resize(150,30);
    SearchWidget->setWindowFlags(Qt::Popup);

    QLineEdit *SearchLineEdit = new QLineEdit(SearchWidget);
    SearchLineEdit->setObjectName("SearchLineEdit");
    SearchLineEdit->resize(150,30);
    SearchLineEdit->move(0,0);
    SearchLineEdit->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
    connect(SearchLineEdit, SIGNAL(textChanged(QString)),this, SLOT(LineEdit_textChanged(QString)));

    if(QX11Info::isCompositingManagerRunning())
            {
            QString SearchStyleSheet =
                    "#SearchWidget {background:transparent;}"
                    "#SearchLineEdit {float:right;margin: 5 0 0 5; border: 2px solid; border-color:rgba(137,137,137,230); color:rgba(137,137,137,230); border-radius: 12px; background-color: rgba(255,255,255,150);}";
            SearchWidget->setStyleSheet(SearchStyleSheet);
            SearchWidget->setAttribute(Qt::WA_TranslucentBackground, true);
            }
            else
                {
                QString SearchStyleSheet =
                        "#SearchWidget { margin:0px;}"
                        "#SearchLineEdit {float:right;margin: 0 0 0 0; border: 2px solid; border-color:rgba(107,107,107,255); color:rgba(187,187,187,250); border-radius: 2px; background-color: rgba(255,255,255,180);}";
                SearchWidget->setStyleSheet(SearchStyleSheet);
                }

    int x,y;
    x = pos().x() + ui->toolBar->pos().x() + (ui->toolBar->width() - SearchWidget->width());
    y = pos().y() + ui->toolBar->pos().y() + ui->toolBar->height() + 20;
    SearchWidget->move(x - 1, y);

        FilterList.clear();
        SearchLineEdit->clear();
        ui->StationslistWidget->clear();
        for (int i = 0; i < tableWidget->rowCount(); i++)
            {
            QListWidgetItem *itemX;
            if (tableWidget->item(i,4)->text() == "Favorite")
                itemX = new QListWidgetItem(QIcon(":/images/IMG/favorite128.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::UserType);
            else
                itemX = new QListWidgetItem(QIcon(":/images/IMG/note128.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::UserType);
            itemX->setToolTip(QString::fromUtf8(SName.toStdString().c_str()) + tableWidget->item(i,0)->text() + "<br>" + QString::fromUtf8(SAddress.toStdString().c_str()) + tableWidget->item(i,1)->text() + "<br>" + QString::fromUtf8(SGenre.toStdString().c_str()) + tableWidget->item(i,2)->text() + "<br>" + QString::fromUtf8(SRegion.toStdString().c_str()) + tableWidget->item(i,3)->text());

            FilterList << tableWidget->item(i,0)->text();
            }

        FilterList.sort();
        SearchLineEdit->setPlaceholderText(QString::fromUtf8(LangTypeStationNameHere.toStdString().c_str()));//

    SearchWidget->show();
    SearchLineEdit->setFocus();

}
//------------------------------------------------------------------------------------

void MainWindow::LineEdit_textChanged(const QString &arg1)
{
    QRegExp FilterRegExp(arg1, Qt::CaseInsensitive, QRegExp::Wildcard);
    ui->StationslistWidget->clear();
    ui->StationslistWidget->addItems(FilterList.filter(FilterRegExp));
    for (int i = 0; i < ui->StationslistWidget->count(); i++)
            {
            QString Item_i(ui->StationslistWidget->item(i)->text());

            for (int q = 0; q < tableWidget->rowCount(); q++)
                {
                if (tableWidget->item(q,0)->text() == Item_i)
                    {
                    if (tableWidget->item(q,4)->text() == "Favorite")
                        ui->StationslistWidget->item(i)->setIcon(QIcon(":/images/IMG/favorite128.png"));
                    else
                        ui->StationslistWidget->item(i)->setIcon(QIcon(":/images/IMG/note128.png"));

                    ui->StationslistWidget->item(i)->setToolTip(QString::fromUtf8(SName.toStdString().c_str()) + tableWidget->item(q,0)->text() + "<br>" + QString::fromUtf8(SAddress.toStdString().c_str()) + tableWidget->item(q,1)->text() + "<br>" + QString::fromUtf8(SGenre.toStdString().c_str()) + tableWidget->item(q,2)->text() + "<br>" + QString::fromUtf8(SRegion.toStdString().c_str()) + tableWidget->item(q,3)->text());
                    }
                }
            //ui->StationslistWidget->item(i)->setIcon(QIcon(":/images/IMG/note128.png"));
            }
    ui->StationslistWidget->scrollToTop();
}
//------------------------------------------------------------------------------------

void MainWindow::OpenAddNewStationDialog()
{
    SaveStations();
    StopRadioStationButton_clicked();

        AddDialog *D;
        D = new AddDialog(this);
        D->exec();

        if (D->AddCancelTriger)
        {
        AddNewStationFunction(D->StationName, D->StationAddress, D->StationGenre, D->StationCountry, D->FavoriteONOFF);
        }
}
//------------------------------------------------------------------------------------

void MainWindow::OpenSettingsDialog()
{
    Settings *S = new Settings(this);

    if (S->exec())
    {
    HideAppCheckBox = S->HideAppCheckBox;
    PlayStationRadioButton = S->PlayStationRadioButton;
    PlayThisStationComboBox = S->PlayThisStationComboBox;
    PlayLastStationRadioButton = S->PlayLastStationRadioButton;
    PlayStationAutomaticly = S->PlayStationAutomaticly;
    ShowStationsSystemTray = S->ShowStationsSystemTray;
    ShowSystemTrayMessage = S->ShowSystemTrayMessage;
    HideOnMinimize = S->HideOnMinimize;
    IconTheme_White = S->IconTheme_White;
    ShowWindowInStyleMode = S->ShowWindowInStyleMode;
    StyleName = S->StyleName;
    UILanguage = S->UILanguage;

    EnableVisualisation = S->EnableVisualisation;
    VisualisationLineWidth = S->VisualisationLineWidth;
    VisualisationOpacitySlider = S->VisualisationOpacitySlider;
    LeftChannelColor = S->LeftChannelColor;
    RightChannelColor = S->RightChannelColor;
    LeftChannelPosition = S->LeftChannelPosition;
    RightChannelPosition = S->RightChannelPosition;
    UseLeftChannel = S->UseLeftChannel;
    UseRightChannel = S->UseRightChannel;
    }

    writeSettings();

    //Procitaj i postavi jezik
    QSettings temp_settings("glrp", "Great Little Radio Player");
    temp_settings.beginGroup("OtherSettings");
    ReadLanguage(temp_settings.value("UILanguage", "English").toString());
    temp_settings.endGroup();
    //-----------------------

    readSettings();

    DoAsYouReadSettings();
    SetWindowStyle(false, StyleName);

    if ((S->CoutModeChanged) || (S->CoatChanged))
    {
    close();
    QProcess::startDetached(qApp->arguments()[0], qApp->arguments());
    }
}
//------------------------------------------------------------------------------------
void MainWindow::OpenAboutDialog()
{
    AboutDialog *AD = new AboutDialog(this);
    AD->exec();
}

//------------------------------------------------------------------------------------

void MainWindow::writeSettings()
{
    QSettings settings("glrp", "Great Little Radio Player");
    settings.beginGroup("MainWindow");
    settings.setValue("size", size());
    settings.setValue("pos", pos());
    settings.setValue("splitterSizes", ui->splitter->saveState());
    settings.setValue("StationListWidgetViewMode", ui->StationslistWidget->viewMode());
    settings.setValue("StationListWidgetIconSize", ui->StationslistWidget->iconSize());
    settings.setValue("isWrapping", ui->StationslistWidget->isWrapping());
    settings.setValue("Version", QApplication::applicationVersion());

    settings.endGroup();
    settings.beginGroup("OtherSettings");
    settings.setValue("HideApp", HideAppCheckBox);
    settings.setValue("PlayAutomaticly", PlayStationAutomaticly);
    settings.setValue("PlayStation", PlayStationRadioButton);
    settings.setValue("PlayThisStation", PlayThisStationComboBox);
    settings.setValue("PlayLastStation", PlayLastStationRadioButton);
    if (PlayName != "") //Ne zelimo da se zapise da nije pustano nista, jer ranije je ipak nesto pustano i to treba da ostane
    settings.setValue("LastStationName", PlayName);//Zato sto je PlayName upravo ta stanica koja je zadnje pustana
    settings.setValue("ShowStationsSystemTray", ShowStationsSystemTray);
    settings.setValue("ShowBaloonMessages", ShowSystemTrayMessage);
    settings.setValue("UILanguage", UILanguage);
    settings.setValue("ShowWindowInStyleMode",ShowWindowInStyleMode);
    settings.setValue("StyleName",StyleName);
    settings.setValue("HideOnMinimize", HideOnMinimize);
    settings.setValue("IconTheme_White", IconTheme_White);
    settings.setValue("EnableVisualisation", EnableVisualisation);
    settings.setValue("VisualisationLineWidth", VisualisationLineWidth);
    settings.setValue("VisualisationOpacitySlider", VisualisationOpacitySlider);
    settings.setValue("LeftChannelColor", LeftChannelColor);
    settings.setValue("RightChannelColor", RightChannelColor);
    settings.setValue("LeftChannelPosition", LeftChannelPosition);
    settings.setValue("RightChannelPosition", RightChannelPosition);
    settings.setValue("UseLeftChannel", UseLeftChannel);
    settings.setValue("UseRightChannel", UseRightChannel);
    settings.endGroup();
}
//------------------------------------------------------------------------------------

void MainWindow::readSettings()
{
    QSettings settings("glrp", "Great Little Radio Player");
    settings.beginGroup("MainWindow");
    resize(settings.value("size", QSize(800, 450)).toSize());
    move(settings.value("pos", QApplication::desktop()->availableGeometry().center() - this->rect().center()).toPoint());

    QByteArray ba(settings.value("splitterSizes").toByteArray());
    if (!ba.isEmpty())
        ui->splitter->restoreState(settings.value("splitterSizes").toByteArray());
        else
            ui->splitter->setStretchFactor(1,1);

    if (settings.value("StationListWidgetViewMode", 1) == 1)
        {ui->StationslistWidget->setViewMode(QListView::IconMode);}
        else
            {ui->StationslistWidget->setViewMode(QListView::ListMode);}
    IconSize = settings.value("StationListWidgetIconSize", QSize(48, 48)).toSize();
    isIconWrapping = settings.value("isWrapping", true).toBool();
    RestoreIconSize(IconSize, isIconWrapping);
    settings.endGroup();

    settings.beginGroup("OtherSettings");
    HideAppCheckBox = settings.value("HideApp", true).toBool();
    PlayStationAutomaticly = settings.value("PlayAutomaticly", false).toBool();
    PlayStationRadioButton = settings.value("PlayStation", false).toBool();
    PlayThisStationComboBox = settings.value("PlayThisStation", "TDI Radio").toString();
    PlayLastStationRadioButton = settings.value("PlayLastStation", true).toBool();
    LastStationName = settings.value("LastStationName", "TDI Radio").toString();
    ShowStationsSystemTray = settings.value("ShowStationsSystemTray", false).toBool();
    ShowSystemTrayMessage = settings.value("ShowBaloonMessages", true).toBool();
    UILanguage = settings.value("UILanguage", "English").toString();
    ShowWindowInStyleMode = settings.value("ShowWindowInStyleMode", false).toBool();
    StyleName = settings.value("StyleName", "Carpent.qss").toString();
    HideOnMinimize = settings.value("HideOnMinimize", true).toBool();
    IconTheme_White = settings.value("IconTheme_White", true).toBool();
    EnableVisualisation = settings.value("EnableVisualisation", false).toBool();
    VisualisationLineWidth = settings.value("VisualisationLineWidth",3).toInt();
    VisualisationOpacitySlider = settings.value("VisualisationOpacitySlider", 150).toInt();
    LeftChannelColor = settings.value("LeftChannelColor").value<QColor>();
    if (!LeftChannelColor.isValid())
        {LeftChannelColor.setRgb(88,88,88,VisualisationOpacitySlider);}
    RightChannelColor = settings.value("RightChannelColor").value<QColor>();
    if (!RightChannelColor.isValid())
        {RightChannelColor.setRgb(255,255,255,VisualisationOpacitySlider);}
    LeftChannelPosition = settings.value("LeftChannelPosition",10).toInt();
    RightChannelPosition = settings.value("RightChannelPosition",10).toInt();
    UseLeftChannel = settings.value("UseLeftChannel", true).toBool();
    UseRightChannel = settings.value("UseRightChannel", true).toBool();
    settings.endGroup();
}
//------------------------------------------------------------------------------------
void MainWindow::DoAsYouReadSettings()
{
if (PlayStationAutomaticly)
{
//PlayStation
QString S;
if (PlayStationRadioButton)
    {
    S = PlayThisStationComboBox;
    }
    else if (PlayLastStationRadioButton)
        {
        S = LastStationName;
        }
if (!S.isEmpty())
{
//PlayAfterStartup
try
    {
    for (int i = 0; i < tableWidget->rowCount(); i++)
    {
        if (S == tableWidget->item(i,0)->text())
            {
            PlayName = tableWidget->item(i,0)->text();
            PlayAddress = tableWidget->item(i,1)->text();
            PlayCountry = tableWidget->item(i,3)->text();
            PlayGenre = tableWidget->item(i,2)->text();
            PlayFavorite = tableWidget->item(i,4)->text();
            break;
            }
    }
    PlayMusic(PlayName,PlayAddress);
    StopMenuItem->setText(QString::fromUtf8(LangStopStation.toStdString().c_str()) + "'" + PlayName + "'");
    StopMenuItem->setVisible(true);

    ui->widget->show();
    }catch(...){}
}
}
//Show/Hide app
if (HideAppCheckBox) hide();
else show();
//---END---

if (IconTheme_White)
myicon = QIcon(":/images/IMG/radio-tray-white-32.png");
else
    myicon = QIcon(":/images/IMG/radio-white-72.png");

trayIcon->setIcon(myicon);
}

//------------------------------------------------------------------------------------

void MainWindow::ExpandCollapse()
{
    if (ui->actionExpand_Collapse->isChecked())
    ui->GenreCountryStringTreeWidget->expandAll();
    else
    ui->GenreCountryStringTreeWidget->collapseAll();
}
//------------------------------------------------------------------------------------
void MainWindow::MaximizeRestore()
{
    if (windowState() != Qt::WindowMaximized)
    setWindowState(Qt::WindowMaximized);
    else
        {
        setWindowState(Qt::WindowNoState);
         QDesktopWidget *d = QApplication::desktop();
         int w = d->width();
         int h = d->height();
         int mw = width();
         int mh = height();
         int cw = (w/2) - (mw/2);
         int ch = (h/2) - (mh/2);
         setGeometry(50,50,700,350);
         move(cw,ch);
        }
}

//------------------------------------------------------------------------------------
void MainWindow::mousePressEvent(QMouseEvent* event)
{
    if (event->button() == Qt::LeftButton)
    {
    dragPosition = event->globalPos() - frameGeometry().topLeft();
    event->accept();
    }
}
//------------------------------------------------------------------------------------
void MainWindow::mouseMoveEvent(QMouseEvent* event)
{
    if (event->buttons() & Qt::LeftButton)
    {
    move(event->globalPos() - dragPosition);
    event->accept();
    }

    if (event->buttons() & Qt::RightButton)
        {
        QPoint Posit;
        Posit = frameGeometry().topLeft();
        int x = event->globalX() - Posit.rx();
        int y = event->globalY() - Posit.ry();
        QSize Size(x, y);
        resize(Size);
        event->accept();
        }
}

//------------------------------------------------------------------------------------

void MainWindow::ImportStationsFromFile()
{
SaveStations();

QMessageBox msgBox;
msgBox.setText("<font size=5>" + QString::fromUtf8(LangImportTitle.toStdString().c_str()) + "</font>");
msgBox.setInformativeText(QString("<table width='100%' border='0'><tr><td align='center' width='15%'><img src='" + QString(":/images/IMG/glrp128.png'/>")) + QString("</td><td>" + QString::fromUtf8(LangImportInformativeText.toStdString().c_str())));

QPushButton *LocateStationsButton = msgBox.addButton(QString::fromUtf8(LangImportLocateButton.toStdString().c_str()), QMessageBox::ActionRole);
QPushButton *CancelButton = msgBox.addButton(QString::fromUtf8(CancelButtonText.toStdString().c_str()), QMessageBox::RejectRole);

msgBox.setDefaultButton(LocateStationsButton);
msgBox.exec();

if (msgBox.clickedButton() == LocateStationsButton)
{
//Open Local Station File for comaring
QTableWidget *LocalTableWidget = new QTableWidget();;


    QFile OpenFile(PathToStationsFile);
    if (OpenFile.exists())
    {
            if(OpenFile.open(QIODevice::ReadOnly))
                {
                QTextStream ts( &OpenFile );
                QList<QStringList> list;
                int row = 0, col = 0;

                while( !ts.atEnd() )
                    {
                    list << ts.readLine().split( "," );
                    }
                OpenFile.close();

                LocalTableWidget->setRowCount( list.count() );
                LocalTableWidget->setColumnCount( list[0].count() );

                LocalTableWidget->setUpdatesEnabled( false );
                foreach( QStringList l, list )
                {
                    foreach( QString str, l )
                    {

                        if( str.endsWith( '"' ) ) str.chop(1);
                        if( str.startsWith( '"' ) ) str.remove(0,1);
                        LocalTableWidget->setItem( row, col++, new QTableWidgetItem( str ));
                    }
                    row++; col=0;
                }
                LocalTableWidget->setUpdatesEnabled( true );
            }
       }

//Open Import Station File for comaring
QTableWidget *ImportTableWidget = new QTableWidget();;
QString fileName = QFileDialog::getOpenFileName(this, tr("Open CSV file"),"", tr("CSV File (*.csv)"));


        QFile OpenImportFile(fileName);
        if (OpenImportFile.exists())
        {
                if(OpenImportFile.open(QIODevice::ReadOnly))
                    {

                    QTextStream ts( &OpenImportFile );
                    QList<QStringList> list;
                    int row = 0, col = 0;

                    while( !ts.atEnd() )
                        {
                        list << ts.readLine().split( "," );
                        }
                    OpenImportFile.close();

                    ImportTableWidget->setRowCount( list.count() );
                    ImportTableWidget->setColumnCount( list[0].count() );

                    ImportTableWidget->setUpdatesEnabled( false );
                    foreach( QStringList l, list )
                    {
                        foreach( QString str, l )
                        {

                            if( str.endsWith( '"' ) ) str.chop(1);
                            if( str.startsWith( '"' ) ) str.remove(0,1);
                            ImportTableWidget->setItem( row, col++, new QTableWidgetItem( str ));
                        }
                        row++; col=0;
                    }

                    ImportTableWidget->setUpdatesEnabled( true );
                }
           }

        //----------------------------

        QStringList ListOfNewAddresses;
        ListOfNewAddresses.clear();
        QStringList ListOfSameAddresses;
        ListOfSameAddresses.clear();
        bool foundsameaddress = false;

        for (int i = 0; i < ImportTableWidget->rowCount(); i++)
            {
            QString SingleImportAddres = ImportTableWidget->item(i,1)->text();

            for (int n = 0; n < LocalTableWidget->rowCount(); n++)
                {
                QString SingleLocalAddres = LocalTableWidget->item(n,1)->text();

                if (SingleImportAddres == SingleLocalAddres)
                    {
                    foundsameaddress = true;
                    ListOfSameAddresses << SingleImportAddres;
                    break;
                    }
                else
                    {
                    foundsameaddress = false;
                    }
                }
            if (!foundsameaddress)
            ListOfNewAddresses << SingleImportAddres;
            }

        //----------------------------
        QMessageBox InfoMsgBox;
        QPushButton *ImportStationsButton = InfoMsgBox.addButton(QString::fromUtf8(ImpostStationsButtonText.toStdString().c_str()), QMessageBox::ActionRole);
        QPushButton *CancelButton = InfoMsgBox.addButton(QString::fromUtf8(CancelButtonText.toStdString().c_str()), QMessageBox::RejectRole);

        InfoMsgBox.setText(QString::fromUtf8(LangImportFinishTitle.toStdString().c_str()));
        QString One(QString::fromUtf8(LangImportFinishInformativeText1.toStdString().c_str()) + QString("\n") + PathToStationsFile + QString("\n") + QString::fromUtf8(LangImportFinishInformativeText2.toStdString().c_str()) + QString::number(LocalTableWidget->rowCount()));
        QString Two(QString::fromUtf8(LangImportFinishInformativeText3.toStdString().c_str()) + QString("\n") + fileName + QString("\n") + QString::fromUtf8(LangImportFinishInformativeText4.toStdString().c_str()) + QString::number(ImportTableWidget->rowCount()));

        QString Tree;
        if (ListOfNewAddresses.count() > 0)
            {
            Tree = QString::fromUtf8(LangImportFinishInformativeText5.toStdString().c_str()) + QString::number(ListOfNewAddresses.count()) + QString::fromUtf8(LangStations.toStdString().c_str());
            }
                else
                {
                Tree = QString::fromUtf8(LangImportFinishInformativeText6.toStdString().c_str());
                ImportStationsButton->setEnabled(false);
                }

        QString Four;
        if (ListOfSameAddresses.count() > 0)
            {
            Four  = QString::fromUtf8(LangImportFinishInformativeText7.toStdString().c_str()) + QString::number(ListOfSameAddresses.count()) + QString::fromUtf8(LangStations.toStdString().c_str());
            }
            else
                {
                Four  = QString::fromUtf8(LangImportFinishInformativeText8.toStdString().c_str());
                }

        InfoMsgBox.setInformativeText(One + "\n\n" + Two + "\n\n\n" + Tree + "\n" + Four);
        InfoMsgBox.setDefaultButton(ImportStationsButton);
        InfoMsgBox.exec();

        //Really Importing
        if (InfoMsgBox.clickedButton() == ImportStationsButton)
        {
        for (int i = 0; i < ListOfNewAddresses.count(); i++)//ListOfNewAddresses.count()
            {
            for (int n = 0; n < ImportTableWidget->rowCount(); n++)
                {
                if (ListOfNewAddresses.at(i) == ImportTableWidget->item(n,1)->text())
                    {
                    AddStationsOneByOneFunction(ImportTableWidget->item(n,0)->text(), ImportTableWidget->item(n,1)->text(), ImportTableWidget->item(n,2)->text(), ImportTableWidget->item(n,3)->text(), ImportTableWidget->item(n,4)->text());
                    }
                }
            }
        }
        else if (InfoMsgBox.clickedButton() == CancelButton)
        {
        InfoMsgBox.close();
        }

SaveStations();
RefreshGenreCountryList("Genre");
StatusGenre = true;
ShowFavorites();
}
else if(msgBox.clickedButton() == CancelButton)
    {
    msgBox.close();
    }
}

//------------------------------------------------------------------------------------
void MainWindow::ExportStations()
{
    //Provera da li postoji fajl sa jezicima i stanicama i ako ne postoji, pravljenje jednog takvog fajla
    PathToStationsDir = QDir::homePath() + "/.config/glrp/";
    PathToStationsFile = PathToStationsDir + "stations.csv";

    QFile LocalStationsFile(PathToStationsFile);
    if (LocalStationsFile.exists())
        {
        QFile DestinationStationsFile(QFileDialog::getSaveFileName());

        if ((!DestinationStationsFile.fileName().isEmpty()) && (DestinationStationsFile.fileName() != LocalStationsFile.fileName()))
            {
            LocalStationsFile.copy(LocalStationsFile.fileName(),DestinationStationsFile.fileName());
            }
            else
                {
                QMessageBox ErrorBox;
                ErrorBox.setIcon(QMessageBox::Critical);
                ErrorBox.setText("ERROR");
                ErrorBox.setInformativeText("Something is wrong with destination file name, it is empty or it is same as source file. Please, repeet with right file name as destination.");
                ErrorBox.exec();
                }
        }
}

//------------------------------------------------------------------------------------

void MainWindow::RestoreIconSize(QSize IconSize, bool isIconWrapping)
{
ui->StationslistWidget->setIconSize(IconSize);
ui->StationslistWidget->setWrapping(isIconWrapping);

if (isIconWrapping)
    ui->StationslistWidget->setViewMode(QListView::IconMode);
else
    {
    ui->StationslistWidget->setViewMode(QListView::ListMode);
    }

RefreshAlignment();
}

//------------------------------------------------------------------------------------

void MainWindow::UserIconSize()
{
    if (sender()->objectName() == "action16x16_List")
    {
    ui->action16x16_List->setChecked(true);
    ui->StationslistWidget->setViewMode(QListView::ListMode);
    QSize size(16, 16);
    ui->StationslistWidget->setIconSize(size);
    ui->StationslistWidget->setWrapping(false);
    }
    if (sender()->objectName() == "action22x22_List")
    {
    ui->action22x22_List->setChecked(true);
    ui->StationslistWidget->setViewMode(QListView::ListMode);
    QSize size(22, 22);
    ui->StationslistWidget->setIconSize(size);
    ui->StationslistWidget->setWrapping(false);
    }
    else if(sender()->objectName() == "action32x32_List")
    {
    ui->action32x32_List->setChecked(true);
    ui->StationslistWidget->setViewMode(QListView::ListMode);
    QSize size(32, 32);
    ui->StationslistWidget->setIconSize(size);
    ui->StationslistWidget->setWrapping(false);
    }
    else if(sender()->objectName() == "action32x32_Icon")
    {
    ui->action32x32_Icon->setChecked(true);
    ui->StationslistWidget->setViewMode(QListView::IconMode);
    QSize size(32, 32);
    ui->StationslistWidget->setIconSize(size);
    ui->StationslistWidget->setWrapping(true);
    }
    else if(sender()->objectName() == "action48x48")
    {
    ui->action48x48->setChecked(true);
    ui->StationslistWidget->setViewMode(QListView::IconMode);
    QSize size(48, 48);
    ui->StationslistWidget->setIconSize(size);
    ui->StationslistWidget->setWrapping(true);
    }
    else if(sender()->objectName() == "action56x56_Icon")
    {
    ui->action56x56_Icon->setChecked(true);
    ui->StationslistWidget->setViewMode(QListView::IconMode);
    QSize size(56, 56);
    ui->StationslistWidget->setIconSize(size);
    ui->StationslistWidget->setWrapping(true);
    }
    else if(sender()->objectName() == "action72x72")
    {
    ui->action72x72->setChecked(true);
    ui->StationslistWidget->setViewMode(QListView::IconMode);
    QSize size(72, 72);
    ui->StationslistWidget->setIconSize(size);
    ui->StationslistWidget->setWrapping(true);
    }
    else if(sender()->objectName() == "action96x96")
    {
    ui->action96x96->setChecked(true);
    ui->StationslistWidget->setViewMode(QListView::IconMode);
    QSize size(96, 96);
    ui->StationslistWidget->setIconSize(size);
    ui->StationslistWidget->setWrapping(true);
    }
    else if(sender()->objectName() == "action128x128")
    {
    ui->action128x128->setChecked(true);
    ui->StationslistWidget->setViewMode(QListView::IconMode);
    QSize size(128, 128);
    ui->StationslistWidget->setIconSize(size);
    ui->StationslistWidget->setWrapping(true);
    }

RefreshAlignment();
}

//------------------------------------------------------------------------------------

void MainWindow::RefreshAlignment()
{
    for (int i = 0; i < ui->StationslistWidget->count(); i++)
            {
            if (ui->StationslistWidget->viewMode() == QListView::IconMode)
                {
                ui->StationslistWidget->item(i)->setTextAlignment(Qt::AlignCenter);
                ui->StationslistWidget->setTextElideMode(Qt::ElideRight);
                }
            else
                {
                ui->StationslistWidget->item(i)->setTextAlignment(Qt::AlignJustify | Qt::AlignVCenter);
                ui->StationslistWidget->setTextElideMode(Qt::ElideNone);
                }
            }
    ui->StationslistWidget->scrollToTop();
}
//------------------------------------------------------------------------------------

void MainWindow::SetWindowStyle(bool HideNow, QString StyleName)
{
ui->BufferprogressBar->setParent(ui->label);
ui->BufferprogressBar->move(ui->label->x(),ui->label->height() - 4);
ui->BufferprogressBar->resize(ui->label->width(),2);

ui->menuBar->hide();

QString ClassicStyleSheet;

    if (ShowWindowInStyleMode)
    {
    this->hide();

        QFile File("/usr/share/glrp/styles/" + StyleName);

    if (File.exists())
        {
        //COAT MODE
        ui->Bar->show();
        ui->toolBar->hide();

        File.open(QFile::ReadOnly);

        QString ClearStyleSheet;
        ClearStyleSheet.clear();
        setStyleSheet(ClearStyleSheet);

        QString StyleSheet = QString(File.readAll());
        setStyleSheet(StyleSheet);

        ui->frame_2->setFrameShape(QFrame::NoFrame);
        ui->frame_2->setFrameShadow(QFrame::Plain);

        ui->GenreCountryStringTreeWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        ui->GenreCountryStringTreeWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        ui->StationslistWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        ui->StationslistWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        ui->main_widget->setContentsMargins(10,10,10,10);

        setWindowFlags(Qt::FramelessWindowHint|Qt::Window);
        setAttribute(Qt::WA_TranslucentBackground, true);
        }
    else
        {
        ShowWindowInStyleMode = false;
        SetWindowStyle(false, StyleName);
        }

    //Show/Hide app
    if (HideNow) hide();
    else show();
    //---END---
    }
    else
    {
    //CLASSIC MODE
    this->hide();

    ClassicStyleSheet.clear();
    ClassicStyleSheet = "#GenreCountryStringTreeWidget {background:transparent;}"
                        "#GenreCountryStringTreeWidget::item {padding:4px;}"
                        "#GenreCountryStringTreeWidget::item:hover {padding:4px; color: rgb(0,0,0);}"
                        "#GenreCountryStringTreeWidget::item:selected {padding:4px; background:transparent; color: rgb(0,0,0); font-weight: bold;}"
                        "#StationslistWidget {background:transparent;}"
                        "#StationslistWidget::item {padding:2px;border: 1px solid;border-color: transparent; border-radius: 12px;}"
                        "#StationslistWidget::item:hover {padding:2px;border: 1px solid;border-color: rgb(185,185,185); border-radius: 12px;}"
                        "#StationslistWidget::item:selected {padding:2px;border: 1px solid;border-color: rgb(135,135,135); color: rgb(125,125,125); border-radius: 12px;}"
                        "#frame_2 {border: 0px solid; border-radius: 8px; }"
                        "#StopButton {margin:2px; min-width: 62px; min-height: 62px; border-radius: 30px; qproperty-text: ""; background:transparent; image: url(:/images/IMG/disconnect128-light.png) stretch;}"
                        "#StopButton:hover {image: url(:/images/IMG/disconnect128.png);}"
                        "#StopButton:pressed {image: url(:/images/IMG/disconnect128-pressed.png);}"
                        "#PauseButton {border-radius: 15px; qproperty-text: "";background:transparent;image: url(:/images/IMG/pausecornernormal48.png);min-width: 24px;min-height: 24px;max-width: 24px;max-height: 24px;}"
                        "#PauseButton:hover {image: url(:/images/IMG/pausecornerhovered48.png);}"
                        "#PauseButton:checked {image: url(:/images/IMG/pausecornerpressed48.png);}"
                        "#BufferprogressBar {border: none;background: transparent;}"
                        "#BufferprogressBar::chunk {background-color: rgba(21, 137, 255, 150);}";

    setStyleSheet(ClassicStyleSheet);

    this->setWindowFlags(Qt::Window);
    ui->StationslistWidget->scrollToBottom();

    setAttribute(Qt::WA_TranslucentBackground, false);
    ui->centralWidget->setAttribute(Qt::WA_TranslucentBackground, false);
    ui->Bar->hide();
    ui->toolBar->show();
    //ui->menuBar->show();

    ui->GenreCountryStringTreeWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
    ui->GenreCountryStringTreeWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
    ui->StationslistWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
    ui->StationslistWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
    ui->main_widget->setContentsMargins(3,3,3,3);

    //Show/Hide app
    if (HideNow) hide();
    else show();
    //---END---

    ui->StopButton->resize(ui->widget->height(),ui->widget->height());
    }


    ui->PauseButton->resize(30,30);
    ui->PauseButton->move(0,0);
    ui->PauseButton->show();


    //Postavljanje statusa vidljivosti u meni za prikazivanje tj sakrivanje playera
    if (isVisible()) ShowHide->setText(QString::fromUtf8(LangHidePlayer.toStdString().c_str()));
    else if (!isVisible()) ShowHide->setText(QString::fromUtf8(LangShowPlayer.toStdString().c_str()));
}

//------------------------------------------------------------------------------------
void MainWindow::ReadLanguage(QString Language)
{
    try
    {
    //Language Settings - MainWindow
    QString LanguagesPath("/usr/share/glrp/language/");
    QString LanguageFilePath(LanguagesPath + Language);
    QSettings LangSettings(LanguageFilePath, QSettings::IniFormat);

    LangSettings.beginGroup("MainWindow");
    LangStations = LangSettings.value("LangStations", " stations").toString();
    LangThisStationComeFrom = LangSettings.value("LangThisStationComeFrom", "This station come from: ").toString();
    LangHidePlayer = LangSettings.value("LangHidePlayer", "Hide player").toString();
    LangShowPlayer = LangSettings.value("LangShowPlayer", "Show player").toString();
    LangExit = LangSettings.value("LangExit", "Exit").toString();
    LangError1 = LangSettings.value("LangError1", "ERROR! We did not made local 'Great Little Radio Player' path: ").toString();
    LangError1a = LangSettings.value("LangError1a", ". Sorry!").toString();
    LangError2 = LangSettings.value("LangError2", "ERROR! We did not set local glrp station file: ").toString();
    LangAbout = LangSettings.value("LangAbout", "About").toString();
    LangFavorite = LangSettings.value("LangFavorite", "Favorite").toString();
    LangDelete = LangSettings.value("LangDelete", "Delete").toString();
    LangDeleteInfo1 = LangSettings.value("LangDeleteInfo1", "Radio station ").toString();
    LangDeleteInfo1a = LangSettings.value("LangDeleteInfo1a", " will be deleted.").toString();
    LangDeleteInfo1b= LangSettings.value("LangDeleteInfo1b", "If you choose YES, there is no turning back! The station will be permanently removed from local resource on your computer, that will not affect on other users.<br>Do you really want to do that?").toString();
    LangDeleteInfo2 = LangSettings.value("LangDeleteInfo2", "Clever!").toString();
    LangDeleteInfo2a = LangSettings.value("LangDeleteInfo2a", "You deside to keep ").toString();
    LangDeleteInfo2b = LangSettings.value("LangDeleteInfo2b", " station.").toString();
    LangStopStation = LangSettings.value("LangStopStation", "Stop '").toString();
    LangPause = LangSettings.value("LangPause", "Pause playing station").toString();//new
    LangPaused = LangSettings.value("LangPaused", "Paused").toString();//new
    LangPlayPaused = LangSettings.value("LangPlayPaused", "Play paused station").toString();//new
    LangPleaseWait = LangSettings.value("LangPleaseWait", "Please wait...").toString();//new
    LangCheckVersion1 = LangSettings.value("LangCheckVersion1", "One time message: Version changed!").toString();//new
    LangCheckVersion2 = LangSettings.value("LangCheckVersion2", "You have upgraded to new version: ").toString();//new
    LangCheckVersion3 = LangSettings.value("LangCheckVersion3", "We have renamed old stations file: ").toString();//new
    LangCheckVersion4 = LangSettings.value("LangCheckVersion4", "If you want, you can restore your personal stations from that file.").toString();//new
    LangCheckVersion5 = LangSettings.value("LangCheckVersion5", "New file with stations will be replaced!").toString();//new

    LangStationSaved1 = LangSettings.value("LangStationSaved1", "Congratulation, station is saved!").toString();
    LangStationSaved1a = LangSettings.value("LangStationSaved1a", "Now you can choose it from the station list!").toString();
    LangFrom = LangSettings.value("LangFrom", "From: ").toString();
    LangGenre = LangSettings.value("LangGenre", "Genre: ").toString();

    LangTypeStationNameHere = LangSettings.value("LangTypeStationNameHere", "Type station name here!").toString();

    LangActionTipsAddNewStation = LangSettings.value("LangActionTipsAddNewStation", "Add new station").toString();
    LangActionTipsSortByCountry = LangSettings.value("LangActionTipsSortByCountry", "Sort by Country").toString();
    LangActionTipsSortByGenre = LangSettings.value("LangActionTipsSortByGenre", "Sort by Genre").toString();
    LangActionTipsExpandColapse = LangSettings.value("LangActionTipsExpandColapse", "Expand/Collapse").toString();
    LangActionTipsShowAllFavorites = LangSettings.value("LangActionTipsShowAllFavorites", "Show all Favorites").toString();
    LangActionTipsShowHideFilter = LangSettings.value("LangActionTipsShowHideFilter", "Show/Hide Filter Stations").toString();
    LangActionTipsShowSettings = LangSettings.value("LangActionTipsShowSettings", "Settings").toString();

    LangMaximizeRestore = LangSettings.value("LangMaximizeRestore", "Maximize / Restore").toString();

    LangImportTitle = LangSettings.value("LangImportTitle", "This is dialog for importing personal stations collection in to Great Little Radio Player.").toString();
    LangImportInformativeText = LangSettings.value("LangImportInformativeText", "It accepts only standard csv file. This type of files has special kind of formating so don't try importing from other types.<br>You should know something about THIS CSV formating:<ul><li>There should be five columns separated with comma.</li><li>If stations Name have comma in it, it will break that station formating.</li><li>Name, Address, Genre, Country and Favorite data should be in double quote</li></ul><br>If you get bad formating after importing stations from unchecked source file, you have one of two solutions to fix this:<ul><li>To delete local file from ~/.conf/glrp/stations.csv ('.config' folder is hidden) and it will be replaced in next application run.</li><li>To edit that file with simple text editor and fix formating using instructions above.</li></ul><br></td></tr></table>In next dialog you will be asked to locate that personal file. It will be merged with local stations file. Only diferent stations from local collection will be imported. The same stations will be lefted. Before importing you will be informed what will be done for confirmation!\n\n Do you want to continue?").toString();
    LangImportLocateButton = LangSettings.value("LangImportLocateButton", "Locate file").toString();

    ImpostStationsButtonText = LangSettings.value("ImpostStationsButtonText", "Import").toString();
    LangImportFinishTitle = LangSettings.value("LangImportFinishTitle", "This is what will be done!").toString();
    LangImportFinishInformativeText1 = LangSettings.value("LangImportFinishInformativeText1", "Local stations file: ").toString();
    LangImportFinishInformativeText2 = LangSettings.value("LangImportFinishInformativeText2", "All count of stations before importing: ").toString();
    LangImportFinishInformativeText3 = LangSettings.value("LangImportFinishInformativeText3", "Import stations file: ").toString();
    LangImportFinishInformativeText4 = LangSettings.value("LangImportFinishInformativeText4", "All count of stations in file: ").toString();
    LangImportFinishInformativeText5 = LangSettings.value("LangImportFinishInformativeText5", "Will be imported, new stations: ").toString();
    LangImportFinishInformativeText6 = LangSettings.value("LangImportFinishInformativeText6", "Nothing to be import...").toString();
    LangImportFinishInformativeText7 = LangSettings.value("LangImportFinishInformativeText7", "Will NOT be imported, found in local collection: ").toString();
    LangImportFinishInformativeText8 = LangSettings.value("LangImportFinishInformativeText8", "Nothing is lefted...").toString();

    LangImpostMenu1 = LangSettings.value("LangImpostMenu1", "Import/Export").toString();
    LangImpostMenu2 = LangSettings.value("LangImpostMenu2", "Import stations from file").toString();
    LangImpostMenu3 = LangSettings.value("LangImpostMenu3", "Export stations to file").toString();
    LangStationsView = LangSettings.value("LangStationsView", "Stations View").toString();
    LangMenuStations = LangSettings.value("LangMenuStations", "Stations").toString();
    LangMenuView = LangSettings.value("LangMenuView", "View").toString();
    LangMenuInfo = LangSettings.value("LangMenuInfo", "Info").toString();

    //Naknadno napravljene QString Language variable
    LangVolumeText = LangSettings.value("LangVolumeText", "Volume").toString();
    EditingStationsByExternalEditorText = LangSettings.value("EditingStationsByExternalEditorText", "Edit stations file in external editor").toString();
    EditingStationsByExternalEditorInfo = LangSettings.value("EditingStationsByExternalEditorInfo", "This process will open stations file in external editor and close this application for secure storing changes. After you made changes, open player again.").toString();

    //Stations

    ui->menuStations->setTitle(QString::fromUtf8(LangMenuStations.toStdString().c_str()));
    ui->actionAdd_new_station->setText(QString::fromUtf8(LangActionTipsAddNewStation.toStdString().c_str()));
    ui->actionAdd_new_station->setToolTip(QString::fromUtf8(LangActionTipsAddNewStation.toStdString().c_str()));
    ui->NewButton->setToolTip(QString::fromUtf8(LangActionTipsAddNewStation.toStdString().c_str()));
    ui->actionHide_player->setText(QString::fromUtf8(LangHidePlayer.toStdString().c_str()));
    ui->actionHide_player->setToolTip(QString::fromUtf8(LangHidePlayer.toStdString().c_str()));
    ui->HideButton->setToolTip(QString::fromUtf8(LangHidePlayer.toStdString().c_str()));
    ui->FavoriteButton->setToolTip(QString::fromUtf8(LangFavorite.toStdString().c_str()));
    ui->MaxRestButton->setToolTip(QString::fromUtf8(LangMaximizeRestore.toStdString().c_str()));
    ui->actionExit->setText(QString::fromUtf8(LangExit.toStdString().c_str()));
    ui->ExitButton->setToolTip(QString::fromUtf8(LangExit.toStdString().c_str()));
    ui->actionExit->setToolTip(QString::fromUtf8(LangExit.toStdString().c_str()));
    ui->menuImport_Export->setTitle(QString::fromUtf8(LangImpostMenu1.toStdString().c_str()));
    ui->actionImport_stations_from_file->setText(QString::fromUtf8(LangImpostMenu2.toStdString().c_str()));
    ui->actionExport_all_stations->setText(QString::fromUtf8(LangImpostMenu3.toStdString().c_str()));
    ui->actionEdit_stations_file->setText(QString::fromUtf8(EditingStationsByExternalEditorText.toStdString().c_str()));

    //View
     ui->menuView->setTitle(QString::fromUtf8(LangMenuView.toStdString().c_str()));
     ui->actionSort_stations_by_Country->setText(QString::fromUtf8(LangActionTipsSortByCountry.toStdString().c_str()));
     ui->actionSort_stations_by_Country->setToolTip(QString::fromUtf8(LangActionTipsSortByCountry.toStdString().c_str()));
     ui->CountryButton->setToolTip(QString::fromUtf8(LangActionTipsSortByCountry.toStdString().c_str()));
     ui->actionSort_stations_by_Genre->setText(QString::fromUtf8(LangActionTipsSortByGenre.toStdString().c_str()));
     ui->actionSort_stations_by_Genre->setToolTip(QString::fromUtf8(LangActionTipsSortByGenre.toStdString().c_str()));
     ui->GenreButton->setToolTip(QString::fromUtf8(LangActionTipsSortByGenre.toStdString().c_str()));
     ui->actionExpand_Collapse->setText(QString::fromUtf8(LangActionTipsExpandColapse.toStdString().c_str()));
     ui->actionExpand_Collapse->setToolTip(QString::fromUtf8(LangActionTipsExpandColapse.toStdString().c_str()));
     ui->actionList_all_Favorites->setText(QString::fromUtf8(LangActionTipsShowAllFavorites.toStdString().c_str()));
     ui->actionList_all_Favorites->setToolTip(QString::fromUtf8(LangActionTipsShowAllFavorites.toStdString().c_str()));
     ui->actionFilter_station_list->setText(QString::fromUtf8(LangActionTipsShowHideFilter.toStdString().c_str()));
     ui->actionFilter_station_list->setToolTip(QString::fromUtf8(LangActionTipsShowHideFilter.toStdString().c_str()));
     ui->actionSettings->setText(QString::fromUtf8(LangActionTipsShowSettings.toStdString().c_str()));
     ui->actionSettings->setToolTip(QString::fromUtf8(LangActionTipsShowSettings.toStdString().c_str()));
     ui->SettingsButton->setToolTip(QString::fromUtf8(LangActionTipsShowSettings.toStdString().c_str()));
     ui->menuStation_View->setTitle(QString::fromUtf8(LangStationsView.toStdString().c_str()));
     ui->actionPause->setText(QString::fromUtf8(LangPause.toStdString().c_str()));
     ui->actionPause->setToolTip(QString::fromUtf8(LangPause.toStdString().c_str()));

    //Info
     ui->menuAbout->setTitle(QString::fromUtf8(LangMenuInfo.toStdString().c_str()));
     ui->actionAll_about->setText(QString::fromUtf8(LangAbout.toStdString().c_str()));
     ui->actionAll_about->setToolTip(QString::fromUtf8(LangAbout.toStdString().c_str()));

     ui->VolumeButton->setToolTip(QString::fromUtf8(LangVolumeText.toStdString().c_str()));

    LangSettings.endGroup();

    LangSettings.beginGroup("AddNewStation");
    SName = LangSettings.value("SName","Name: ").toString();
    SAddress = LangSettings.value("SAddress","Address: ").toString();
    SGenre = LangSettings.value("SGenre","Genre: ").toString();
    SRegion = LangSettings.value("SRegion","Country/Region: ").toString();

    CancelButtonText = LangSettings.value("CancelButtonText","Cancel").toString();
    AddButtonText = LangSettings.value("AddButtonText","Add").toString();
    ResetButtonText = LangSettings.value("ResetButtonText","Reset").toString();
    LangSettings.endGroup();
    }
    catch(...){}
}

//------------------------------------------------------------------------------------

void MainWindow::ShowVolumeWindow()
{
    int x,y;
    x = pos().x() + ui->VolumeButton->pos().x() + (ui->VolumeButton->width()/2);
    y = pos().y() + ui->VolumeButton->pos().y() + ui->VolumeButton->height() + 10;
    volumeSlider2->move(x - 1, y);
    //volumeSlider2->move(QCursor::pos().x() - 10, QCursor::pos().y() + 10);
    if (ShowWindowInStyleMode)
    {
    QFile File("/usr/share/glrp/styles/" + StyleName);
    if (File.exists())
        {
        File.open(QFile::ReadOnly);
        QString StyleSheet = QString(File.readAll());
        volumeSlider2->setStyleSheet(StyleSheet);
        }
    }
    volumeSlider2->setAttribute(Qt::WA_TranslucentBackground, true);
    volumeSlider2->show();
}

//------------------------------------------------------------------------------------

void MainWindow::EditStationsFile()
{
    QFile stationsfile(QDir::homePath() + QDir::separator() + ".config/glrp/stations.csv");

    if (stationsfile.exists())
    {
    QMessageBox mbox;
    mbox.setText(QString::fromUtf8(EditingStationsByExternalEditorInfo.toStdString().c_str()));
    mbox.exec();
    QDesktopServices Process;
    Process.openUrl(QUrl(stationsfile.fileName()));
    close();
    }
}

//------------------------------------------------------------------------------------

void MainWindow::OpenMenu()
{
QMenu *main_menu = new QMenu;

    main_menu->addMenu(ui->menuStations);
    main_menu->addMenu(ui->menuView);
    main_menu->addSeparator();
    main_menu->addAction(ui->actionSettings);
    main_menu->addAction(ui->actionAll_about);
    main_menu->addSeparator();
    main_menu->addAction(ui->actionExit);

    int aX, aY;
    aY = QCursor::pos().y() + 25;
    aX = QCursor::pos().x();

    QCursor *aCursor = new QCursor;
    aCursor->setPos(aX,aY);

    main_menu->exec(aCursor->pos());//
}

//------------------------------------------------------------------------------------

void MainWindow::PorukaMala(QString text)
{
    QMessageBox m;
    m.setText(text);
    m.exec();
}

//------------------------------------------------------------------------------------

void MainWindow::PorukaVelika(QMessageBox::Icon Icon, QString text, QString infotext)
{
    QMessageBox m;
    if (Icon == QMessageBox::Information)
        m.setIcon(QMessageBox::Information);
    if (Icon == QMessageBox::Warning)
        m.setIcon(QMessageBox::Warning);
    if (Icon == QMessageBox::Critical)
        m.setIcon(QMessageBox::Critical);
    if (Icon == QMessageBox::Question)
        m.setIcon(QMessageBox::Question);
    if (Icon == QMessageBox::NoIcon)
        m.setIcon(QMessageBox::NoIcon);

    m.setWindowTitle(QApplication::applicationName());
    m.setText(text);
    m.setInformativeText(infotext);
    m.exec();
}

//------------------------------------------------------------------------------------
