#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QSystemTrayIcon>
#include "QTreeWidgetItem"
#include "QListWidgetItem"
#include <QSortFilterProxyModel>
#include <QStandardItemModel>
#include "phonon/MediaObject"
#include "phonon/AudioDataOutput"
#include "QMessageBox"
#include "QTableWidgetItem"
#include <phonon/VolumeSlider>

namespace Ui {class MainWindow;}
class MainWindow : public QMainWindow
{
    Q_OBJECT
    QMap<Phonon::AudioDataOutput::Channel, QVector<qint16> > audiopodatci;
    void paintEvent(QPaintEvent *event);

public:
    explicit MainWindow(QWidget *parent = 0);
    void PlayMusic(QString /*StationName*/, QString StationAddress);
    QSize IconSize;
    bool isIconWrapping;
    QString TITLE;
    bool HideAppCheckBox;
    bool  PlayStationRadioButton;
    QString PlayThisStationComboBox;
    bool PlayLastStationRadioButton;
    QString LastStationName;
    bool PlayStationAutomaticly;
    bool ShowStationsSystemTray;
    bool ShowSystemTrayMessage;
    QString UILanguage;
    bool ShowWindowInStyleMode;
    QString StyleName;
    bool HideOnMinimize;
    bool EnableVisualisation;
    int VisualisationLineWidth;
    int VisualisationOpacitySlider;
    QColor LeftChannelColor, RightChannelColor;
    int LeftChannelPosition, RightChannelPosition;
    bool UseLeftChannel, UseRightChannel;
    bool IconTheme_White;

    QString IMGLabel_StatusString;
    QString StationLabelStatusString;
    QString StationNameStatusFont;
    QString PlayName, PlayAddress, PlayCountry, PlayGenre, PlayFavorite;
    QString Artist, CurrentArtist, Album, Title;

    Phonon::MediaObject *music;
    Phonon::AudioOutput *audioOutput;
    Phonon::AudioDataOutput *audioDataOutput;
    Phonon::VolumeSlider *volumeSlider;
    Phonon::VolumeSlider *volumeSlider2;

    QAction *StopMenuItem;
    QAction *PauseMenuItem;
    QAction *FavoriteOnOffMenuItem;
    QAction *DeleteMenuItem;
    QAction *About;
    QAction *ShowHide;

    QTableWidget *tableWidget;
    QWidget *emptyWidget;
    QImage *image;
    QIcon myicon;

    QString PathToStationsDir;
    QString PathToDestLanguageDir;
    QString PathToOrigLanguageDir;
    QString PathToStationsFile;
    QStringList FilterList;
    QString IsFavoriteIcon;

    bool Playing;
    bool StatusGenre;
    bool StatusCountry;

    //Language Settings - MainWindow
    QString LangStations;
    QString LangThisStationComeFrom;
    QString LangHidePlayer,LangShowPlayer;
    QString LangExit;
    QString LangError1,LangError1a,LangError2;
    QString LangAbout;
    QString LangFavorite;
    QString LangDelete,LangDeleteInfo1,LangDeleteInfo1a,LangDeleteInfo1b,LangDeleteInfo2,LangDeleteInfo2a,LangDeleteInfo2b;
    QString LangStopStation,LangPause,LangPaused,LangPlayPaused;
    QString LangCheckVersion1,LangCheckVersion2,LangCheckVersion3,LangCheckVersion4,LangCheckVersion5;
    QString LangStationSaved1,LangStationSaved1a;
    QString LangFrom;
    QString LangGenre;
    QString LangTypeStationNameHere;
    QString LangActionTipsAddNewStation,LangActionTipsSortByCountry,LangActionTipsSortByGenre,LangActionTipsExpandColapse,LangActionTipsShowAllFavorites,LangActionTipsShowHideFilter,LangActionTipsShowSettings;
    QString SName,SAddress,SGenre,SRegion;
    QString CancelButtonText,AddButtonText,ResetButtonText;
    QString LangPleaseWait;
    QString LangImpostMenu1,LangImpostMenu2,LangImpostMenu3;
    QString LangStationsView;
    QString LangMenuView;
    QString LangMenuStations;
    QString LangMenuInfo;
    QString LangVolumeText;
    QString LangEnjoy;
    QString ImpostStationsButtonText,LocateStationsButtonText;
    QString OK;
    QString LangMaximizeRestore;
    QString LangImportTitle,LangImportInformativeText,LangImportLocateButton;
    QString LangImportFinishTitle,LangImportFinishInformativeText1,LangImportFinishInformativeText2,LangImportFinishInformativeText3,LangImportFinishInformativeText4,LangImportFinishInformativeText5,LangImportFinishInformativeText6,LangImportFinishInformativeText7,LangImportFinishInformativeText8;
    QString EditingStationsByExternalEditorInfo,EditingStationsByExternalEditorText;
    ~MainWindow();

private slots:
        void SystemTray(bool ContextMenuIsVisible);
        void TrayIconActivated(QSystemTrayIcon::ActivationReason razlog);
        void SaveStations();
        void Load_stations(QString PathToStationsFile);
        void SloveIfStationFileNotExists();
        void InformSystemAboutSong();
        void RefreshGenreCountryList(QString arg1);
        void AddNewStationFunction(QString StationName, QString StationAddress, QString StationGenre, QString StationCountry, QString FavoriteONOFF);
        void AddStationsOneByOneFunction(QString StationName, QString StationAddress, QString StationGenre, QString StationCountry, QString FavoriteONOFF);
        void ShowContextMenu(const QPoint& pos);
        void SetOrRemoveFavorite();
        void DeleteStation();
        void TrayPlayMusic();
        //void ShowMainWindow();
        void LineEdit_textChanged(const QString &arg1);
        void writeSettings();
        void readSettings();
        void DoAsYouReadSettings();
        void ReadLanguage(QString Language);
        void SetWindowStyle(bool HideNow, QString StyleName);
        void RestoreIconSize(QSize IconSize, bool isIconWrapping);
        void UserIconSize();
        void RefreshAlignment();
        void bufferStatusToTitle(int percentFilled);
        void CheckVersion();
        void stateChanged(Phonon::State newState, Phonon::State /**/);
        void metaDataChanged();
        void ShowVolumeWindow();
        void changeEvent(QEvent *event);
        void PorukaMala(QString text);
        void PorukaVelika(QMessageBox::Icon Icon, QString text, QString infotext);

public slots:
        void AudioSignalRecived(const QMap<Phonon::AudioDataOutput::Channel, QVector<qint16> > &data);
        void CreateConnection();
        void OpenAddNewStationDialog();
        void GenreCountryItemClicked(QTreeWidgetItem *item, int /*column*/);
        void StationClicked(QListWidgetItem *item);
        void StopRadioStationButton_clicked();
        void SortStationsByCountry();
        void SortStationsByGenre();
        void ShowFavorites();
        void ShowHideWindow();
        void FilterStations();
        void OpenSettingsDialog();
        void OpenAboutDialog();
        void ImportStationsFromFile();
        void ExportStations();
        void ExpandCollapse();
        void MaximizeRestore();
        void Pause();
        void EditStationsFile();
        void OpenMenu();
        void Exit();

protected:
        void mouseMoveEvent(QMouseEvent *event);
        void mousePressEvent(QMouseEvent *event);

private:
        Ui::MainWindow *ui;
        QPoint dragPosition;
        void FilterStations(QString GenreCountry, QString SelectedItem);
        int m_alpha;
        QAction *minimizeAction;
        QAction *maximizeAction;
        QAction *restoreAction;
        QAction *quitAction;
        QSystemTrayIcon *trayIcon;
        QMenu *trayMenu;
};

#endif // MAINWINDOW_H
