#include "settings.h"
#include "ui_settings.h"
#include "mainwindow.h"
#include <QSettings>
#include <QtCore/QFile>
#include <QDir>
#include "QTableWidgetItem"
#include <QTextStream>
#include "QPushButton"
#include <QX11Info>
#include "QMessageBox"
#include <QPalette>

QTableWidget *TestTableWidget3;
QString PathToStationsDir3;
QString PathToStationsFile3;

//------------------------------------------------------------------------------------

Settings::Settings(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::Settings)
{
    ui->setupUi(this);

    mailto = "<a href='mailto:dekiseka.petrovic@gmail.com'>dekiseka.petrovic@gmail.com</a>";
    website = "<a href='https://sites.google.com/site/glrpgreatlittleradioplayer/'>Official website!</a>";
    websiteTips = "<a href='https://sites.google.com/site/glrpgreatlittleradioplayer/home/tips'>See tips!</a>";

    QSettings temp_settings("glrp", "Great Little Radio Player");
    temp_settings.beginGroup("OtherSettings");
    ReadLanguage(temp_settings.value("UILanguage", "English").toString());
    temp_settings.endGroup();

    QString Image("<img src=':/images/IMG/settings.png'/>");
    ui->MainLabel1->setText("<table><tr><td align=center width='70'>" + QString(Image) + "</td><td align=justify><font size=4>" + QString::fromUtf8(LangSettingsTitle.toStdString().c_str()) + "</font><br>" + QString(QString::fromUtf8(LangSettingsInfo.toStdString().c_str())) + "</td></tr></table>");
    setWindowTitle(QString::fromUtf8(LangSettingsTitle.toStdString().c_str()));

    LoadStationsToAutoPlayList();
    SearchForStyleFiles();
    SearchForLanguageFiles();
    readSettings();

    //ui->buttonBox->setCenterButtons(true);
    ui->buttonBox->clear();
    ui->buttonBox->setFocus();
    QPushButton *OKButton = new QPushButton(QString::fromUtf8(OKButtonText.toStdString().c_str()));
    OKButton->setDefault(true);
    QPushButton *CancelButton = new QPushButton(QString::fromUtf8(CancelButtonText.toStdString().c_str()));
    CancelButton->setAutoDefault(false);
    QPushButton *resetButton = new QPushButton(QString::fromUtf8(ResetButtonText.toStdString().c_str()));


    ui->buttonBox->addButton(OKButton, QDialogButtonBox::AcceptRole);
    ui->buttonBox->addButton(CancelButton, QDialogButtonBox::RejectRole);
    ui->buttonBox->addButton(resetButton, QDialogButtonBox::ResetRole);

    connect(resetButton, SIGNAL(clicked()), this, SLOT(ResetToDefault()));
    connect(ui->buttonBox,SIGNAL(accepted()),this,SLOT(AcceptSettings()));

    CoutModeChanged = false;
    CoatChanged = false;

    resetButton->setDefault(false);
    CancelButton->setDefault(false);
    OKButton->setDefault(true);
    OKButton->setFocus();
}

//------------------------------------------------------------------------------------

Settings::~Settings()
{
    delete ui;
}

//------------------------------------------------------------------------------------

void Settings::ResetToDefault()
{
    ui->HideAppCheckBox1->setChecked(false);
    ui->PlayStationRadioButton1->setChecked(false);
    ui->PlayThisStationComboBox1->itemText(0);
    ui->PlayLastStationRadioButton1->setChecked(false);
    ui->PlayStationAutomaticly1->setChecked(false);
    ui->ShowStationsSystemTrayComboBox1->setChecked(false);
    ui->ShowSystemTrayMessageCheckBox1->setChecked(true);
    ui->LangcomboBox1->setCurrentIndex(ui->LangcomboBox1->findText("English.lng"));
    ui->StyleBox->setChecked(false);
    ui->StyleComboBox->itemText(0);
    ui->HideOnMinimizeCheckBox->setChecked(true);
    ui->radioButtonWhite->setChecked(true);
}

//------------------------------------------------------------------------------------

void Settings::AcceptSettings()
{
HideAppCheckBox = ui->HideAppCheckBox1->isChecked();
PlayStationRadioButton = ui->PlayStationRadioButton1->isChecked();
PlayThisStationComboBox = ui->PlayThisStationComboBox1->itemText(ui->PlayThisStationComboBox1->currentIndex());
PlayLastStationRadioButton = ui->PlayLastStationRadioButton1->isChecked();
PlayStationAutomaticly = ui->PlayStationAutomaticly1->isChecked();
ShowStationsSystemTray = ui->ShowStationsSystemTrayComboBox1->isChecked();
ShowSystemTrayMessage = ui->ShowSystemTrayMessageCheckBox1->isChecked();
UILanguage = ui->LangcomboBox1->currentText();
ShowWindowInStyleMode = ui->StyleBox->isChecked();
StyleName = ui->StyleComboBox->currentText();
HideOnMinimize = ui->HideOnMinimizeCheckBox->isChecked();
IconTheme_White = ui->radioButtonWhite->isChecked();
EnableVisualisation = ui->VisualisationGroupBox->isChecked();
VisualisationLineWidth = ui->LineSpinBox->value();
VisualisationOpacitySlider = ui->VisualisationOpacitySlider->value();
LeftChannelPosition = ui->LeftChannelPositionSlider->value();
RightChannelPosition = ui->RightChannelPositionSlider->value();
UseLeftChannel = ui->LeftChannelLabel->isChecked();
UseRightChannel = ui->RightChannelLabel->isChecked();
}

//------------------------------------------------------------------------------------

void Settings::readSettings()
{
    QSettings settings("glrp", "Great Little Radio Player");

    settings.beginGroup("OtherSettings");
    HideAppCheckBox = settings.value("HideApp", true).toBool();
    PlayStationRadioButton = settings.value("PlayStation", false).toBool();
    PlayThisStationComboBox = settings.value("PlayThisStation", "").toString();
    PlayLastStationRadioButton = settings.value("PlayLastStation", false).toBool();
    PlayStationAutomaticly = settings.value("PlayAutomaticly", false).toBool();
    ShowStationsSystemTray = settings.value("ShowStationsSystemTray", false).toBool();
    ShowSystemTrayMessage = settings.value("ShowBaloonMessages", true).toBool();
    UILanguage = settings.value("UILanguage", "English").toString();
    ShowWindowInStyleMode = settings.value("ShowWindowInStyleMode", false).toBool();
    StyleName = settings.value("StyleName", "Aluminum.qss").toString();
    HideOnMinimize = settings.value("HideOnMinimize", true).toBool();
    IconTheme_White = settings.value("IconTheme_White", true).toBool();
    EnableVisualisation = settings.value("EnableVisualisation", false).toBool();
    VisualisationLineWidth = settings.value("VisualisationLineWidth",3).toInt();
    VisualisationOpacitySlider = settings.value("VisualisationOpacitySlider", 150).toInt();
    LeftChannelColor = settings.value("LeftChannelColor").value<QColor>();
    if (!LeftChannelColor.isValid())
        {LeftChannelColor.setRgb(88,88,88,VisualisationOpacitySlider);}
    RightChannelColor = settings.value("RightChannelColor").value<QColor>();
    if (!RightChannelColor.isValid())
        {RightChannelColor.setRgb(255,255,255,VisualisationOpacitySlider);}
    LeftChannelPosition = settings.value("LeftChannelPosition",10).toInt();
    RightChannelPosition = settings.value("RightChannelPosition",10).toInt();
    UseLeftChannel = settings.value("UseLeftChannel", true).toBool();
    UseRightChannel = settings.value("UseRightChannel", true).toBool();

    settings.endGroup();

     ui->HideAppCheckBox1->setChecked(HideAppCheckBox);
     ui->PlayStationRadioButton1->setChecked(PlayStationRadioButton);
     ui->PlayThisStationComboBox1->setEnabled(PlayStationAutomaticly);
     ui->PlayThisStationComboBox1->setCurrentIndex(ui->PlayThisStationComboBox1->findText(PlayThisStationComboBox));
     ui->PlayThisStationComboBox1->setToolTip("<img src=':/images/IMG/note16.png'/>" + QString::fromUtf8(PlayThisStationComboBox.toStdString().c_str()));
     ui->PlayLastStationRadioButton1->setChecked(PlayLastStationRadioButton);
     ui->PlayStationAutomaticly1->setChecked(PlayStationAutomaticly);
     ui->ShowStationsSystemTrayComboBox1->setChecked(ShowStationsSystemTray);
     ui->ShowSystemTrayMessageCheckBox1->setChecked(ShowSystemTrayMessage);
     ui->LangcomboBox1->setCurrentIndex(ui->LangcomboBox1->findText(UILanguage));
     ui->HideOnMinimizeCheckBox->setChecked(HideOnMinimize);

     if (IconTheme_White)
         ui->radioButtonWhite->setChecked(true);
     else
         ui->radioButtonBlack->setChecked(true);


     if (ui->PlayStationAutomaticly1->isChecked() && ui->PlayStationRadioButton1->isChecked())
     ui->PlayThisStationComboBox1->setEnabled(true);

     ui->StyleBox->setChecked(ShowWindowInStyleMode);
     ui->StyleComboBox->setCurrentIndex(ui->StyleComboBox->findText(StyleName));
     on_StyleComboBox_activated(StyleName);

     ui->VisualisationGroupBox->setChecked(EnableVisualisation);
     ui->LineSpinBox->setValue(VisualisationLineWidth);
     ui->VisualisationOpacitySlider->setValue(VisualisationOpacitySlider);

     QPalette p1 = LeftChannelColor;
     ui->LeftChannelColorPushButton->setPalette(p1);
     ui->LeftLine->setPalette(p1);
     ui->LeftChannelColorPushButton->setText("rgb(" + QString::number(LeftChannelColor.toRgb().red()) + "," + QString::number(LeftChannelColor.toRgb().green()) + "," + QString::number(LeftChannelColor.toRgb().blue()) + ")");
     ui->LeftLine->setStyleSheet("#LeftLine{color:" + ui->LeftChannelColorPushButton->text() + ";}");

     QPalette p2 = RightChannelColor;
     ui->RightChannelPushButton->setPalette(p2);
     ui->RightLine->setPalette(p2);
     ui->RightChannelPushButton->setText("rgb(" + QString::number(RightChannelColor.toRgb().red()) + "," + QString::number(RightChannelColor.toRgb().green()) + "," + QString::number(RightChannelColor.toRgb().blue()) + ")");
     ui->RightLine->setStyleSheet("#RightLine{color:" + ui->RightChannelPushButton->text() + ";}");

     ui->LeftChannelPositionSlider->setValue(LeftChannelPosition);
     ui->RightChannelPositionSlider->setValue(RightChannelPosition);
     ui->LeftChannelLabel->setChecked(UseLeftChannel);
     ui->RightChannelLabel->setChecked(UseRightChannel);
}

//------------------------------------------------------------------------------------

void Settings::on_PlayStationRadioButton1_toggled(bool checked)
{
ui->PlayThisStationComboBox1->setEnabled(checked);
}

//------------------------------------------------------------------------------------

void Settings::LoadStationsToAutoPlayList()
{
//Tabela
TestTableWidget3 = new QTableWidget();

PathToStationsDir3 = QDir::homePath() + "/.config/glrp/";
PathToStationsFile3 = PathToStationsDir3 + "stations.csv";

QFile f( PathToStationsFile3 );

    if( f.open( QIODevice::ReadOnly ) )
    {
        QTextStream ts( &f );
        QList<QStringList> list;
        int row = 0, col = 0;


        while( !ts.atEnd() ){
            list << ts.readLine().split( "," );
        }

        f.close();

        TestTableWidget3->setRowCount( list.count() );
        TestTableWidget3->setColumnCount( list[0].count() );

        TestTableWidget3->setUpdatesEnabled( false );
        foreach( QStringList l, list ){
            foreach( QString str, l ){

                if( str.endsWith( '"' ) ) str.chop(1);
                if( str.startsWith( '"' ) ) str.remove(0,1);
                TestTableWidget3->setItem( row, col++, new QTableWidgetItem( str ));
            }
            row++; col=0;
        }
        TestTableWidget3->setUpdatesEnabled( true );
    }
//Kraj Tabele

    //Stringlists and populate
    QStringList StationsList;

    for (int i=0;i<TestTableWidget3->rowCount();i++)
        {
            StationsList << TestTableWidget3->item(i,0)->text();
        }
    StationsList.sort();
    StationsList.removeDuplicates();

    ui->PlayThisStationComboBox1->clear();
    ui->PlayThisStationComboBox1->addItems(StationsList);

    QIcon noteicon = QIcon(":/images/IMG/note16.png");
    for (int a = 0; a <  ui->PlayThisStationComboBox1->count(); a++)
    {
    ui->PlayThisStationComboBox1->setItemIcon(a,noteicon);
    }
}

//------------------------------------------------------------------------------------

void Settings::on_PlayThisStationComboBox1_currentIndexChanged(const QString &arg1)
{
    ui->PlayThisStationComboBox1->setToolTip("<img src=':/images/IMG/note16.png'/>" + arg1);
}

//------------------------------------------------------------------------------------

void Settings::ReadLanguage(QString Language)
{
    //Language Settings - MainWindow
    QString LanguagesPath("/usr/share/glrp/language/");
    QString LanguageFilePath(LanguagesPath + Language);
    QSettings LangSettings(LanguageFilePath, QSettings::IniFormat);

    LangSettings.beginGroup("Settings");
    LangSettingsTitle = LangSettings.value("LangSettingsTitle", "Settings").toString();
    LangSettingsInfo = LangSettings.value("LangSettingsInfo", "Here you can customize behavior of Great Little Radio Player.").toString();
    LangStartupTab = LangSettings.value("LangStartupTab", "On Start Up").toString();
    LangLookAndFeelTab = LangSettings.value("LangLookAndFeelTab", "Look").toString();
    LangLocalization = LangSettings.value("LangLocalization", "Localization").toString();
    LangHideMainWindowCheckBox = LangSettings.value("LangHideMainWindowCheckBox", "Hide main window on application startup\n(Only icon in system tray)").toString();
    PlayStationAutomaticly1 = LangSettings.value("PlayStationAutomaticly1", "Play stations automaticly").toString();
    PlayStationRadioButton1 = LangSettings.value("PlayStationRadioButton1", "Play this station on application startup:").toString();
    PlayLastStationRadioButton1 = LangSettings.value("PlayLastStationRadioButton1", "Play last played station").toString();
    LangShowStationsSystemTray = LangSettings.value("ShowStationsSystemTray", "Show stations and categories in system tray menu\n(application restart is required)").toString();
    LangShowSystemTrayMessage = LangSettings.value("ShowSystemTrayMessage", "Show baloon messages about playing station").toString();
    LaguageGroupBox = LangSettings.value("LaguageGroupBox", "Language:").toString();
    label_localization = LangSettings.value("label_localization", "If you are willing to help by translating this application on your language or improve existing one, please write author on ").toString();
    CompositingManagerON = LangSettings.value("CompositingManagerON", "Compositing Manager Found Running! This will work on your system!").toString();
    CompositingManagerOFF = LangSettings.value("CompositingManagerOFF", "No Compositing Manager Running! This will not work on your system properly!").toString();
    LangStyleBox = LangSettings.value("LangStyleBox", "Coats").toString();
    label_autostartapp = LangSettings.value("label_autostartapp","This station will automaticly start playing on application start.<br>It is useful to choose station which is always available.").toString();
    StyleLabel_a = LangSettings.value("StyleLabel_a", "This feature require compositing manager in run.").toString();
    StyleLabel_b = LangSettings.value("StyleLabel_b", "Note:<br>How to resize 'coat' window? It is little different then resizing other windows. Just <b>right</b> mouse click at the bottom right edge of the window and resize it! ").toString() + websiteTips;
    LangERROR_NOCOATS = LangSettings.value("LangERROR_NOCOATS", "ERROR: NO COATS FOUND (Did you install this app correctly?)").toString();
    LangERROR_NOLANGS = LangSettings.value("LangERROR_NOLANGS", "ERROR: NO LANGUAGES FOUND (Did you install this app correctly?)").toString();
    CancelButtonText = LangSettings.value("CancelButtonText","Cancel").toString();
    OKButtonText = LangSettings.value("OKButtonText","OK").toString();
    ResetButtonText = LangSettings.value("ResetButtonText","Reset to defaults").toString();
    HideOnMinimizeCheckBoxText = LangSettings.value("HideOnMinimizeCheckBoxText","Hide Main window when press minimize button").toString();

    IconThemeGroupBox = LangSettings.value("IconThemeGroupBox","Indicator Icon").toString();
    IconThemeWhite = LangSettings.value("IconThemeWhite","White").toString();
    IconThemeBlack = LangSettings.value("IconThemeBlack","Black").toString();

    LangVisualisation = LangSettings.value("LangVisualisation","Visualisation").toString();
    LangVisualisationEnable = LangSettings.value("LangVisualisationEnable","Enable audio visualisation (visible in classic mode and transparent `coats`)").toString();
    LangChannels = LangSettings.value("LangChannels","Channels").toString();
    LangLeftChannel = LangSettings.value("LangLeftChannel","Left").toString();
    LangRightChannel = LangSettings.value("LangRightChannel","Right").toString();
    LangAlpha = LangSettings.value("LangAlpha","Alpha:").toString();
    LangLineWidth = LangSettings.value("LangLineWidth","Line width:").toString();
    LangPositionText = LangSettings.value("LangPositionText", "Position").toString();

    ui->tabWidget->setTabText(0,QString::fromUtf8(LangStartupTab.toStdString().c_str()));
    ui->tabWidget->setTabText(1,QString::fromUtf8(LangLookAndFeelTab.toStdString().c_str()));
    ui->tabWidget->setTabText(2,QString::fromUtf8(LangVisualisation.toStdString().c_str()));
    ui->tabWidget->setTabText(3,QString::fromUtf8(LangLocalization.toStdString().c_str()));
    ui->HideAppCheckBox1->setText(QString::fromUtf8(LangHideMainWindowCheckBox.toStdString().c_str()));
    ui->PlayStationAutomaticly1->setTitle(QString::fromUtf8(PlayStationAutomaticly1.toStdString().c_str()));
    ui->PlayStationRadioButton1->setText(QString::fromUtf8(PlayStationRadioButton1.toStdString().c_str()));
    ui->PlayLastStationRadioButton1->setText(QString::fromUtf8(PlayLastStationRadioButton1.toStdString().c_str()));
    ui->ShowStationsSystemTrayComboBox1->setText(QString::fromUtf8(LangShowStationsSystemTray.toStdString().c_str()));
    ui->ShowSystemTrayMessageCheckBox1->setText(QString::fromUtf8(LangShowSystemTrayMessage.toStdString().c_str()));
    ui->LanguageBox->setTitle(QString::fromUtf8(LaguageGroupBox.toStdString().c_str()));
    ui->label_localization->setText(QString::fromUtf8(label_localization.toStdString().c_str()) + mailto);
    ui->StyleBox->setTitle(QString::fromUtf8(LangStyleBox.toStdString().c_str()));
    ui->label_autostartapp->setText(QString::fromUtf8(label_autostartapp.toStdString().c_str()));

    ui->groupBoxIndicatorIcon->setTitle(QString::fromUtf8(IconThemeGroupBox.toStdString().c_str()));
    ui->radioButtonWhite->setText(QString::fromUtf8(IconThemeWhite.toStdString().c_str()));
    ui->radioButtonBlack->setText(QString::fromUtf8(IconThemeBlack.toStdString().c_str()));

    ui->VisualisationGroupBox->setTitle(QString::fromUtf8(LangVisualisationEnable.toStdString().c_str()));
    ui->groupBox_3->setTitle(QString::fromUtf8(LangChannels.toStdString().c_str()));
    ui->LeftChannelLabel->setText(QString::fromUtf8(LangLeftChannel.toStdString().c_str()));
    ui->RightChannelLabel->setText(QString::fromUtf8(LangRightChannel.toStdString().c_str()));
    ui->opacitylabel->setText(QString::fromUtf8(LangAlpha.toStdString().c_str()));
    ui->PenWidthLabel->setText(QString::fromUtf8(LangLineWidth.toStdString().c_str()));
    ui->PositionLabel->setText(QString::fromUtf8(LangPositionText.toStdString().c_str()));

    if(!QX11Info::isCompositingManagerRunning())
        {
        //ui->StyleBox->setToolTip(QString::fromUtf8(CompositingManagerOFF.toStdString().c_str()));
        ui->Style_label->setText(QString::fromUtf8(StyleLabel_a.toStdString().c_str()) + QString("<br><font color=red>") + QString::fromUtf8(CompositingManagerOFF.toStdString().c_str()) + QString("</font><br><br>") + QString::fromUtf8(StyleLabel_b.toStdString().c_str()));
        }
    else
    {
    //ui->StyleBox->setToolTip(QString::fromUtf8(CompositingManagerON.toStdString().c_str()));
    ui->Style_label->setText(QString::fromUtf8(StyleLabel_a.toStdString().c_str()) + QString("<br><font color=green>") + QString::fromUtf8(CompositingManagerON.toStdString().c_str()) + QString("</font><br><br>") + QString::fromUtf8(StyleLabel_b.toStdString().c_str()));
    }

    ui->HideOnMinimizeCheckBox->setText(QString::fromUtf8(HideOnMinimizeCheckBoxText.toStdString().c_str()));

    LangSettings.endGroup();
}

//------------------------------------------------------------------------------------

void Settings::on_PlayStationAutomaticly1_toggled(bool arg1)
{
    if (ui->PlayStationAutomaticly1->isChecked() && ui->PlayStationRadioButton1->isChecked())
    ui->PlayThisStationComboBox1->setEnabled(arg1);
}

//------------------------------------------------------------------------------------

void Settings::SearchForStyleFiles()
{
ui->StyleComboBox->clear();

    try
    {
    QStringList nameFilter("*.qss");
    QDir directory("/usr/share/glrp/styles/");
    QStringList FilesAndDirectories = directory.entryList(nameFilter);

    ui->StyleComboBox->addItems(FilesAndDirectories);
    }
    catch(...)
    {
    ui->StyleComboBox->addItem(QString::fromUtf8(LangERROR_NOCOATS.toStdString().c_str()), Qt::DisplayRole);
    ui->StyleComboBox->setCurrentIndex(0);
    }
}

//------------------------------------------------------------------------------------

void Settings::SearchForLanguageFiles()
{
ui->LangcomboBox1->clear();

    try
    {
    QStringList nameFilter("*.lng");
    QDir directory("/usr/share/glrp/language/");
    QStringList FilesAndDirectories = directory.entryList(nameFilter);
    FilesAndDirectories.sort();

    ui->LangcomboBox1->addItems(FilesAndDirectories);
    }
    catch(...)
    {
    ui->LangcomboBox1->addItem("ERROR: NO LANGUAGES FOUND (Did you install this app correctly?)", Qt::DisplayRole);
    ui->LangcomboBox1->setCurrentIndex(0);
    }

}

//------------------------------------------------------------------------------------

void Settings::on_StyleBox_toggled(bool arg1)
{
    CoutModeChanged = true;
}

//------------------------------------------------------------------------------------

void Settings::on_StyleComboBox_activated(const QString &arg1)
{
    try
    {
    QFileInfo Style(arg1);
    QDir directory("/usr/share/glrp/styles/thumbnails/");
    QFile file(directory.path() + QDir::separator() + Style.baseName() + ".png");
    QFile backupfile(directory.path() + QDir::separator() + "NoImage.png");
    QString ClassicStyleSheet;
    ClassicStyleSheet.clear();

    if (file.exists())
    {
    ClassicStyleSheet = "#thumb_widget {image: url(" + file.fileName() + ");}";
    }
    else
    {
    ClassicStyleSheet = "#thumb_widget {image: url(" + backupfile.fileName() + ");}";
    }

    ui->thumb_widget->setStyleSheet(ClassicStyleSheet);
    }
    catch(...){}
}

//------------------------------------------------------------------------------------

void Settings::on_LeftChannelColorPushButton_clicked()
{
    LeftChannelColor = QColorDialog::getColor(LeftChannelColor, this );

    QPalette palette = LeftChannelColor;
    ui->LeftChannelColorPushButton->setPalette(palette);
    ui->LeftChannelColorPushButton->setText("rgb(" + QString::number(LeftChannelColor.toRgb().red()) + "," + QString::number(LeftChannelColor.toRgb().green()) + "," + QString::number(LeftChannelColor.toRgb().blue()) + ")");
    ui->LeftLine->setStyleSheet("#LeftLine{color:" + ui->LeftChannelColorPushButton->text() + ";}");
}
//------------------------------------------------------------------------------------

void Settings::on_RightChannelPushButton_clicked()
{
    RightChannelColor = QColorDialog::getColor(RightChannelColor, this );

    QPalette palette2 = RightChannelColor;
    ui->RightChannelPushButton->setPalette(palette2);
    ui->RightChannelPushButton->setText("rgb(" + QString::number(RightChannelColor.toRgb().red()) + "," + QString::number(RightChannelColor.toRgb().green()) + "," + QString::number(RightChannelColor.toRgb().blue()) + ")");
    ui->RightLine->setStyleSheet("#RightLine{color:" + ui->RightChannelPushButton->text() + ";}");
}
//------------------------------------------------------------------------------------
